# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_storebrowse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.enums_productinfo_pb2 as enums__productinfo__pb2
import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.contenthubs_pb2 as contenthubs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_storebrowse.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x17\x65nums_productinfo.proto\x1a\x0b\x65nums.proto\x1a\x11\x63ontenthubs.proto\"z\n\x0bStoreItemID\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tpackageid\x18\x02 \x01(\r\x12\x10\n\x08\x62undleid\x18\x03 \x01(\r\x12\r\n\x05tagid\x18\x04 \x01(\r\x12\x11\n\tcreatorid\x18\x05 \x01(\r\x12\x15\n\rhubcategoryid\x18\x06 \x01(\r\"d\n\x12StoreBrowseContext\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x11\n\telanguage\x18\x02 \x01(\x05\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12\x13\n\x0bsteam_realm\x18\x04 \x01(\x05\"\xb3\x04\n\x1aStoreBrowseItemDataRequest\x12\x16\n\x0einclude_assets\x18\x01 \x01(\x08\x12\x17\n\x0finclude_release\x18\x02 \x01(\x08\x12\x19\n\x11include_platforms\x18\x03 \x01(\x08\x12$\n\x1cinclude_all_purchase_options\x18\x04 \x01(\x08\x12\x1b\n\x13include_screenshots\x18\x05 \x01(\x08\x12\x18\n\x10include_trailers\x18\x06 \x01(\x08\x12\x17\n\x0finclude_ratings\x18\x07 \x01(\x08\x12\x19\n\x11include_tag_count\x18\x08 \x01(\x05\x12\x17\n\x0finclude_reviews\x18\t \x01(\x08\x12\x1a\n\x12include_basic_info\x18\n \x01(\x08\x12#\n\x1binclude_supported_languages\x18\x0b \x01(\x08\x12 \n\x18include_full_description\x18\x0c \x01(\x08\x12\x1e\n\x16include_included_items\x18\r \x01(\x08\x12?\n\x1aincluded_item_data_request\x18\x0e \x01(\x0b\x32\x1b.StoreBrowseItemDataRequest\x12(\n include_assets_without_overrides\x18\x0f \x01(\x08\x12\x1a\n\x12\x61pply_user_filters\x18\x10 \x01(\x08\x12\x15\n\rinclude_links\x18\x11 \x01(\x08\"\x93\x01\n\x1d\x43StoreBrowse_GetItems_Request\x12\x19\n\x03ids\x18\x01 \x03(\x0b\x32\x0c.StoreItemID\x12$\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x13.StoreBrowseContext\x12\x31\n\x0c\x64\x61ta_request\x18\x03 \x01(\x0b\x32\x1b.StoreBrowseItemDataRequest\"\xec-\n\tStoreItem\x12<\n\titem_type\x18\x01 \x01(\x0e\x32\x0f.EStoreItemType:\x18k_EStoreItemType_Invalid\x12\n\n\x02id\x18\x02 \x01(\r\x12\x0f\n\x07success\x18\x03 \x01(\r\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12*\n\"unvailable_for_country_restriction\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x16\n\x0estore_url_path\x18\x07 \x01(\t\x12\r\n\x05\x61ppid\x18\t \x01(\r\x12\x32\n\x04type\x18\n \x01(\x0e\x32\x0e.EStoreAppType:\x14k_EStoreAppType_Game\x12&\n\x0eincluded_types\x18\x0b \x03(\x0e\x32\x0e.EStoreAppType\x12\x17\n\x0fincluded_appids\x18\x0c \x03(\r\x12\x0f\n\x07is_free\x18\r \x01(\x08\x12\x17\n\x0fis_early_access\x18\x0e \x01(\x08\x12.\n\rrelated_items\x18\x0f \x01(\x0b\x32\x17.StoreItem.RelatedItems\x12\x30\n\x0eincluded_items\x18\x10 \x01(\x0b\x32\x18.StoreItem.IncludedItems\x12\x34\n\x15\x63ontent_descriptorids\x18\x14 \x03(\x0e\x32\x15.EContentDescriptorID\x12\x0e\n\x06tagids\x18\x15 \x03(\r\x12)\n\ncategories\x18\x16 \x01(\x0b\x32\x15.StoreItem.Categories\x12#\n\x07reviews\x18\x17 \x01(\x0b\x32\x12.StoreItem.Reviews\x12(\n\nbasic_info\x18\x18 \x01(\x0b\x32\x14.StoreItem.BasicInfo\x12\x1c\n\x04tags\x18\x19 \x03(\x0b\x32\x0e.StoreItem.Tag\x12!\n\x06\x61ssets\x18\x1e \x01(\x0b\x32\x11.StoreItem.Assets\x12\'\n\x07release\x18\x1f \x01(\x0b\x32\x16.StoreItem.ReleaseInfo\x12\'\n\tplatforms\x18  \x01(\x0b\x32\x14.StoreItem.Platforms\x12%\n\x0bgame_rating\x18! \x01(\x0b\x32\x10.StoreGameRating\x12\x16\n\x0eis_coming_soon\x18\" \x01(\x08\x12\x37\n\x14\x62\x65st_purchase_option\x18( \x01(\x0b\x32\x19.StoreItem.PurchaseOption\x12\x33\n\x10purchase_options\x18) \x03(\x0b\x32\x19.StoreItem.PurchaseOption\x12.\n\x0b\x61\x63\x63\x65ssories\x18* \x03(\x0b\x32\x19.StoreItem.PurchaseOption\x12\x37\n\x14self_purchase_option\x18+ \x01(\x0b\x32\x19.StoreItem.PurchaseOption\x12+\n\x0bscreenshots\x18\x32 \x01(\x0b\x32\x16.StoreItem.Screenshots\x12%\n\x08trailers\x18\x33 \x01(\x0b\x32\x13.StoreItem.Trailers\x12\x39\n\x13supported_languages\x18\x34 \x03(\x0b\x32\x1c.StoreItem.SupportedLanguage\x12\x1f\n\x17store_url_path_override\x18\x35 \x01(\t\x12,\n\x0c\x66ree_weekend\x18\x36 \x01(\x0b\x32\x16.StoreItem.FreeWeekend\x12\x10\n\x08unlisted\x18\x37 \x01(\x08\x12\x12\n\ngame_count\x18\x38 \x01(\r\x12\x15\n\rinternal_name\x18\x39 \x01(\t\x12\x18\n\x10\x66ull_description\x18: \x01(\t\x12\x1b\n\x13is_free_temporarily\x18; \x01(\x08\x12\x33\n\x18\x61ssets_without_overrides\x18< \x01(\x0b\x32\x11.StoreItem.Assets\x12\x36\n\x13user_filter_failure\x18\x46 \x01(\x0b\x32\x19.StoreBrowseFilterFailure\x12\x1e\n\x05links\x18G \x03(\x0b\x32\x0f.StoreItem.Link\x1aW\n\x0cRelatedItems\x12\x14\n\x0cparent_appid\x18\x01 \x01(\r\x12\x12\n\ndemo_appid\x18\x02 \x03(\r\x12\x1d\n\x15standalone_demo_appid\x18\x03 \x03(\r\x1aY\n\rIncludedItems\x12!\n\rincluded_apps\x18\x01 \x03(\x0b\x32\n.StoreItem\x12%\n\x11included_packages\x18\x02 \x03(\x0b\x32\n.StoreItem\x1ao\n\nCategories\x12$\n\x1csupported_player_categoryids\x18\x02 \x03(\r\x12\x1b\n\x13\x66\x65\x61ture_categoryids\x18\x03 \x03(\r\x12\x1e\n\x16\x63ontroller_categoryids\x18\x04 \x03(\r\x1a\xb2\x02\n\x07Reviews\x12?\n\x10summary_filtered\x18\x01 \x01(\x0b\x32%.StoreItem.Reviews.StoreReviewSummary\x12\x41\n\x12summary_unfiltered\x18\x02 \x01(\x0b\x32%.StoreItem.Reviews.StoreReviewSummary\x1a\xa2\x01\n\x12StoreReviewSummary\x12\x14\n\x0creview_count\x18\x01 \x01(\r\x12\x18\n\x10percent_positive\x18\x02 \x01(\x05\x12@\n\x0creview_score\x18\x03 \x01(\x0e\x32\x11.EUserReviewScore:\x17k_EUserReviewScore_None\x12\x1a\n\x12review_score_label\x18\x04 \x01(\t\x1a\xb0\x02\n\tBasicInfo\x12\x19\n\x11short_description\x18\x01 \x01(\t\x12\x38\n\npublishers\x18\x02 \x03(\x0b\x32$.StoreItem.BasicInfo.CreatorHomeLink\x12\x38\n\ndevelopers\x18\x03 \x03(\x0b\x32$.StoreItem.BasicInfo.CreatorHomeLink\x12\x38\n\nfranchises\x18\x04 \x03(\x0b\x32$.StoreItem.BasicInfo.CreatorHomeLink\x12\x18\n\x10\x63\x61psule_headline\x18\x05 \x01(\t\x1a@\n\x0f\x43reatorHomeLink\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1f\n\x17\x63reator_clan_account_id\x18\x02 \x01(\r\x1a$\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x0e\n\x06weight\x18\x02 \x01(\r\x1a\x8b\x03\n\x06\x41ssets\x12\x18\n\x10\x61sset_url_format\x18\x01 \x01(\t\x12\x14\n\x0cmain_capsule\x18\x02 \x01(\t\x12\x15\n\rsmall_capsule\x18\x03 \x01(\t\x12\x0e\n\x06header\x18\x04 \x01(\t\x12\x16\n\x0epackage_header\x18\x05 \x01(\t\x12\x17\n\x0fpage_background\x18\x06 \x01(\t\x12\x14\n\x0chero_capsule\x18\x07 \x01(\t\x12\x17\n\x0fhero_capsule_2x\x18\x08 \x01(\t\x12\x17\n\x0flibrary_capsule\x18\t \x01(\t\x12\x1a\n\x12library_capsule_2x\x18\n \x01(\t\x12\x14\n\x0clibrary_hero\x18\x0b \x01(\t\x12\x17\n\x0flibrary_hero_2x\x18\x0c \x01(\t\x12\x16\n\x0e\x63ommunity_icon\x18\r \x01(\t\x12\x13\n\x0b\x63lan_avatar\x18\x0e \x01(\t\x12\x1c\n\x14page_background_path\x18\x0f \x01(\t\x12\x1b\n\x13raw_page_background\x18\x10 \x01(\t\x1a\xeb\x02\n\x0bReleaseInfo\x12\x1a\n\x12steam_release_date\x18\x01 \x01(\r\x12\x1d\n\x15original_release_date\x18\x02 \x01(\r\x12#\n\x1boriginal_steam_release_date\x18\x03 \x01(\r\x12\x16\n\x0eis_coming_soon\x18\x04 \x01(\x08\x12\x12\n\nis_preload\x18\x05 \x01(\x08\x12#\n\x1b\x63ustom_release_date_message\x18\x06 \x01(\t\x12 \n\x18is_abridged_release_date\x18\x07 \x01(\x08\x12\x1b\n\x13\x63oming_soon_display\x18\x08 \x01(\t\x12\x17\n\x0fis_early_access\x18\n \x01(\x08\x12\x18\n\x10mac_release_date\x18\x14 \x01(\r\x12\x1a\n\x12linux_release_date\x18\x15 \x01(\r\x12\x1d\n\x15limited_launch_active\x18\x16 \x01(\x08\x1a\xd0\x03\n\tPlatforms\x12\x0f\n\x07windows\x18\x01 \x01(\x08\x12\x0b\n\x03mac\x18\x02 \x01(\x08\x12\x15\n\rsteamos_linux\x18\x03 \x01(\x08\x12\x32\n\nvr_support\x18\n \x01(\x0b\x32\x1e.StoreItem.Platforms.VRSupport\x12o\n\x1asteam_deck_compat_category\x18\x0b \x01(\x0e\x32 .ESteamDeckCompatibilityCategory:)k_ESteamDeckCompatibilityCategory_Unknown\x12i\n\x18steam_os_compat_category\x18\x0c \x01(\x0e\x32\x1e.ESteamOSCompatibilityCategory:\'k_ESteamOSCompatibilityCategory_Unknown\x1a~\n\tVRSupport\x12\r\n\x05vrhmd\x18\x01 \x01(\x08\x12\x12\n\nvrhmd_only\x18\x02 \x01(\x08\x12\x10\n\x08htc_vive\x18( \x01(\x08\x12\x13\n\x0boculus_rift\x18) \x01(\x08\x12\x12\n\nwindows_mr\x18* \x01(\x08\x12\x13\n\x0bvalve_index\x18+ \x01(\x08\x1a\xa8\x08\n\x0ePurchaseOption\x12\x11\n\tpackageid\x18\x01 \x01(\x05\x12\x10\n\x08\x62undleid\x18\x02 \x01(\x05\x12\x1c\n\x14purchase_option_name\x18\x03 \x01(\t\x12\x1c\n\x14\x66inal_price_in_cents\x18\x05 \x01(\x03\x12\x1f\n\x17original_price_in_cents\x18\x06 \x01(\x03\x12\x1d\n\x15\x66ormatted_final_price\x18\x08 \x01(\t\x12 \n\x18\x66ormatted_original_price\x18\t \x01(\t\x12\x14\n\x0c\x64iscount_pct\x18\n \x01(\x05\x12\x1b\n\x13\x62undle_discount_pct\x18\x0c \x01(\x05\x12\x17\n\x0fis_free_to_keep\x18\r \x01(\x08\x12$\n\x1cprice_before_bundle_discount\x18\x0e \x01(\x03\x12.\n&formatted_price_before_bundle_discount\x18\x0f \x01(\t\x12<\n\x10\x61\x63tive_discounts\x18\x14 \x03(\x0b\x32\".StoreItem.PurchaseOption.Discount\x12!\n\x19user_can_purchase_as_gift\x18\x1f \x01(\x08\x12\x1d\n\x15is_commercial_license\x18( \x01(\x08\x12$\n\x1cshould_suppress_discount_pct\x18) \x01(\x08\x12/\n hide_discount_pct_for_compliance\x18* \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x13included_game_count\x18+ \x01(\x05:\x01\x31\x12$\n\x1clowest_recent_price_in_cents\x18, \x01(\x03\x12\x19\n\x11requires_shipping\x18- \x01(\x08\x12\x41\n\x0frecurrence_info\x18. \x01(\x0b\x32(.StoreItem.PurchaseOption.RecurrenceInfo\x12\x19\n\x11\x66ree_to_keep_ends\x18/ \x01(\r\x1a\\\n\x08\x44iscount\x12\x17\n\x0f\x64iscount_amount\x18\x01 \x01(\x03\x12\x1c\n\x14\x64iscount_description\x18\x02 \x01(\t\x12\x19\n\x11\x64iscount_end_date\x18\x03 \x01(\r\x1a\xbc\x01\n\x0eRecurrenceInfo\x12\x11\n\tpackageid\x18\x01 \x01(\x05\x12\x1e\n\x16\x62illing_agreement_type\x18\x02 \x01(\x05\x12\x19\n\x11renewal_time_unit\x18\x03 \x01(\x05\x12\x1b\n\x13renewal_time_period\x18\x04 \x01(\x05\x12\x1e\n\x16renewal_price_in_cents\x18\x05 \x01(\x03\x12\x1f\n\x17\x66ormatted_renewal_price\x18\x06 \x01(\t\x1a\xc6\x01\n\x0bScreenshots\x12?\n\x14\x61ll_ages_screenshots\x18\x02 \x03(\x0b\x32!.StoreItem.Screenshots.Screenshot\x12\x45\n\x1amature_content_screenshots\x18\x03 \x03(\x0b\x32!.StoreItem.Screenshots.Screenshot\x1a/\n\nScreenshot\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0f\n\x07ordinal\x18\x02 \x01(\x05\x1a\xa9\x04\n\x08Trailers\x12/\n\nhighlights\x18\x01 \x03(\x0b\x32\x1b.StoreItem.Trailers.Trailer\x12\x33\n\x0eother_trailers\x18\x02 \x03(\x0b\x32\x1b.StoreItem.Trailers.Trailer\x1a-\n\x0bVideoSource\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x1a\x87\x03\n\x07Trailer\x12\x14\n\x0ctrailer_name\x18\x01 \x01(\t\x12\x1a\n\x12trailer_url_format\x18\x02 \x01(\t\x12G\n\x10trailer_category\x18\r \x01(\x0e\x32\x11.ETrailerCategory:\x1ak_ETrailerCategory_Invalid\x12\x35\n\x0ctrailer_480p\x18\x03 \x03(\x0b\x32\x1f.StoreItem.Trailers.VideoSource\x12\x34\n\x0btrailer_max\x18\x04 \x03(\x0b\x32\x1f.StoreItem.Trailers.VideoSource\x12\x35\n\x0cmicrotrailer\x18\x05 \x03(\x0b\x32\x1f.StoreItem.Trailers.VideoSource\x12\x19\n\x11screenshot_medium\x18\n \x01(\t\x12\x17\n\x0fscreenshot_full\x18\x0b \x01(\t\x12\x17\n\x0ftrailer_base_id\x18\x0c \x01(\x05\x12\x10\n\x08\x61ll_ages\x18\x0e \x01(\x08\x1a\x85\x01\n\x11SupportedLanguage\x12\x15\n\telanguage\x18\x01 \x01(\x05:\x02-1\x12\x1f\n\x13\x65\x61\x64\x64itionallanguage\x18\x05 \x01(\x05:\x02-1\x12\x11\n\tsupported\x18\x02 \x01(\x08\x12\x12\n\nfull_audio\x18\x03 \x01(\x08\x12\x11\n\tsubtitles\x18\x04 \x01(\x08\x1a\x41\n\x0b\x46reeWeekend\x12\x12\n\nstart_time\x18\x01 \x01(\r\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\r\x12\x0c\n\x04text\x18\x03 \x01(\t\x1a\\\n\x04Link\x12\x39\n\tlink_type\x18\x01 \x01(\x0e\x32\x0f.EStoreLinkType:\x15k_EStoreLinkType_None\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xb7\x01\n\x0fStoreGameRating\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06rating\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scriptors\x18\x03 \x03(\t\x12\x1c\n\x14interactive_elements\x18\x04 \x01(\t\x12\x14\n\x0crequired_age\x18\n \x01(\x05\x12\x14\n\x0cuse_age_gate\x18\x0b \x01(\x08\x12\x11\n\timage_url\x18\x14 \x01(\t\x12\x14\n\x0cimage_target\x18\x15 \x01(\t\"\xa1\x03\n\x18StoreBrowseFilterFailure\x12T\n\x0e\x66ilter_failure\x18\x01 \x01(\x0e\x32\x1a.EStoreBrowseFilterFailure: k_EStoreBrowseFilterFailure_None\x12\x15\n\ralready_owned\x18\x05 \x01(\x08\x12\x13\n\x0bon_wishlist\x18\x06 \x01(\x08\x12\x0f\n\x07ignored\x18\x07 \x01(\x08\x12\x1d\n\x15not_in_users_language\x18\n \x01(\x08\x12\x1d\n\x15not_on_users_platform\x18\x0b \x01(\x08\x12\x1b\n\x13\x64\x65mo_for_owned_game\x18\x0c \x01(\x08\x12\x1c\n\x14\x64lc_for_unowned_game\x18\r \x01(\x08\x12!\n\x19nonpreferred_product_type\x18\x14 \x01(\x08\x12\x17\n\x0f\x65xcluded_tagids\x18\x15 \x03(\r\x12=\n\x1e\x65xcluded_content_descriptorids\x18\x1e \x03(\x0e\x32\x15.EContentDescriptorID\"A\n\x1e\x43StoreBrowse_GetItems_Response\x12\x1f\n\x0bstore_items\x18\x01 \x03(\x0b\x32\n.StoreItem\"R\n\'CStoreBrowse_GetStoreCategories_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x15\n\telanguage\x18\x02 \x01(\x05:\x02-1\"\xea\x02\n(CStoreBrowse_GetStoreCategories_Response\x12\x46\n\ncategories\x18\x01 \x03(\x0b\x32\x32.CStoreBrowse_GetStoreCategories_Response.Category\x1a\xf5\x01\n\x08\x43\x61tegory\x12\x12\n\ncategoryid\x18\x01 \x01(\r\x12@\n\x04type\x18\x02 \x01(\x0e\x32\x13.EStoreCategoryType:\x1dk_EStoreCategoryType_Category\x12\x15\n\rinternal_name\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\x16\n\x0eshow_in_search\x18\x06 \x01(\x08\x12\x10\n\x08\x63omputed\x18\x07 \x01(\x08\x12\x10\n\x08\x65\x64it_url\x18\x08 \x01(\t\x12\x17\n\x0f\x65\x64it_sort_order\x18\t \x01(\r\"P\n(CStoreBrowse_GetContentHubConfig_Request\x12$\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x13.StoreBrowseContext\"\xed\x01\n)CStoreBrowse_GetContentHubConfig_Response\x12O\n\nhubconfigs\x18\x01 \x03(\x0b\x32;.CStoreBrowse_GetContentHubConfig_Response.ContentHubConfig\x1ao\n\x10\x43ontentHubConfig\x12\x15\n\rhubcategoryid\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0e\n\x06handle\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\x10\n\x08url_path\x18\x05 \x01(\t\"Q\n\"CStoreBrowse_GetPriceStops_Request\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12\x15\n\rcurrency_code\x18\x02 \x01(\t\"\xc1\x01\n#CStoreBrowse_GetPriceStops_Response\x12\x43\n\x0bprice_stops\x18\x01 \x03(\x0b\x32..CStoreBrowse_GetPriceStops_Response.PriceStop\x12\x15\n\rcurrency_code\x18\x02 \x01(\t\x1a>\n\tPriceStop\x12\x18\n\x10\x66ormatted_amount\x18\x01 \x01(\t\x12\x17\n\x0f\x61mount_in_cents\x18\x02 \x01(\x03\"\xa7\x01\n\"CStoreBrowse_GetDLCForApps_Request\x12$\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x13.StoreBrowseContext\x12,\n\x11store_page_filter\x18\x02 \x01(\x0b\x32\x11.CStorePageFilter\x12\x1c\n\x06\x61ppids\x18\x03 \x03(\x0b\x32\x0c.StoreItemID\x12\x0f\n\x07steamid\x18\x04 \x01(\x04\"\xfe\x02\n#CStoreBrowse_GetDLCForApps_Response\x12>\n\x08\x64lc_data\x18\x01 \x03(\x0b\x32,.CStoreBrowse_GetDLCForApps_Response.DLCData\x12\x45\n\x08playtime\x18\x02 \x03(\x0b\x32\x33.CStoreBrowse_GetDLCForApps_Response.PlaytimeForApp\x1a\x87\x01\n\x07\x44LCData\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x13\n\x0bparentappid\x18\x02 \x01(\r\x12\x14\n\x0crelease_date\x18\x03 \x01(\r\x12\x13\n\x0b\x63oming_soon\x18\x04 \x01(\x08\x12\r\n\x05price\x18\x05 \x01(\x03\x12\x10\n\x08\x64iscount\x18\x06 \x01(\r\x12\x0c\n\x04\x66ree\x18\x07 \x01(\x08\x1a\x46\n\x0ePlaytimeForApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08playtime\x18\x02 \x01(\r\x12\x13\n\x0blast_played\x18\x03 \x01(\r\"\xab\x01\n&CStoreBrowse_GetDLCForAppsSolr_Request\x12$\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x13.StoreBrowseContext\x12\x0e\n\x06\x61ppids\x18\x02 \x03(\r\x12\x0e\n\x06\x66lavor\x18\x03 \x01(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\r\x12,\n\x11store_page_filter\x18\x05 \x01(\x0b\x32\x11.CStorePageFilter\"\xa3\x01\n\'CStoreBrowse_GetDLCForAppsSolr_Response\x12\x43\n\tdlc_lists\x18\x01 \x03(\x0b\x32\x30.CStoreBrowse_GetDLCForAppsSolr_Response.DLCList\x1a\x33\n\x07\x44LCList\x12\x14\n\x0cparent_appid\x18\x01 \x01(\r\x12\x12\n\ndlc_appids\x18\x02 \x03(\r\"`\n%CStoreBrowse_GetHardwareItems_Request\x12\x11\n\tpackageid\x18\x01 \x03(\r\x12$\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x13.StoreBrowseContext\"\x94\x04\n\x17\x43HardwarePackageDetails\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x1b\n\x13inventory_available\x18\x03 \x01(\x08\x12\x1b\n\x13high_pending_orders\x18\x04 \x01(\x08\x12*\n\"account_restricted_from_purchasing\x18\x05 \x01(\x08\x12\x1c\n\x14requires_reservation\x18\x06 \x01(\x08\x12$\n\x1crtime_estimated_notification\x18\x07 \x01(\r\x12\x19\n\x11notificaton_token\x18\x08 \x01(\t\x12\x19\n\x11reservation_state\x18\t \x01(\x05\x12\x0f\n\x07\x65xpired\x18\n \x01(\x08\x12\x14\n\x0ctime_expires\x18\x0b \x01(\r\x12\x15\n\rtime_reserved\x18\x0c \x01(\r\x12\x1f\n\x17\x61llow_quantity_purchase\x18\r \x01(\x08\x12!\n\x19max_quantity_per_purchase\x18\x0e \x01(\x05\x12!\n\x19\x61llow_purchase_in_country\x18\x0f \x01(\x08\x12\x30\n(estimated_delivery_soonest_business_days\x18\x11 \x01(\r\x12/\n\'estimated_delivery_latest_business_days\x18\x12 \x01(\r\"S\n&CStoreBrowse_GetHardwareItems_Response\x12)\n\x07\x64\x65tails\x18\x01 \x03(\x0b\x32\x18.CHardwarePackageDetails*\x80\x02\n\x0e\x45StoreItemType\x12%\n\x18k_EStoreItemType_Invalid\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x14k_EStoreItemType_App\x10\x00\x12\x1c\n\x18k_EStoreItemType_Package\x10\x01\x12\x1b\n\x17k_EStoreItemType_Bundle\x10\x02\x12\x18\n\x14k_EStoreItemType_Mtx\x10\x03\x12\x18\n\x14k_EStoreItemType_Tag\x10\x04\x12\x1c\n\x18k_EStoreItemType_Creator\x10\x05\x12 \n\x1ck_EStoreItemType_HubCategory\x10\x06*\xab\x03\n\rEStoreAppType\x12\x18\n\x14k_EStoreAppType_Game\x10\x00\x12\x18\n\x14k_EStoreAppType_Demo\x10\x01\x12\x17\n\x13k_EStoreAppType_Mod\x10\x02\x12\x19\n\x15k_EStoreAppType_Movie\x10\x03\x12\x17\n\x13k_EStoreAppType_DLC\x10\x04\x12\x19\n\x15k_EStoreAppType_Guide\x10\x05\x12\x1c\n\x18k_EStoreAppType_Software\x10\x06\x12\x19\n\x15k_EStoreAppType_Video\x10\x07\x12\x1a\n\x16k_EStoreAppType_Series\x10\x08\x12\x1b\n\x17k_EStoreAppType_Episode\x10\t\x12\x1c\n\x18k_EStoreAppType_Hardware\x10\n\x12\x19\n\x15k_EStoreAppType_Music\x10\x0b\x12\x18\n\x14k_EStoreAppType_Beta\x10\x0c\x12\x18\n\x14k_EStoreAppType_Tool\x10\r\x12\x1f\n\x1bk_EStoreAppType_Advertising\x10\x0e*\x85\x03\n\x10\x45UserReviewScore\x12\x1b\n\x17k_EUserReviewScore_None\x10\x00\x12-\n)k_EUserReviewScore_OverwhelminglyNegative\x10\x01\x12#\n\x1fk_EUserReviewScore_VeryNegative\x10\x02\x12\x1f\n\x1bk_EUserReviewScore_Negative\x10\x03\x12%\n!k_EUserReviewScore_MostlyNegative\x10\x04\x12\x1c\n\x18k_EUserReviewScore_Mixed\x10\x05\x12%\n!k_EUserReviewScore_MostlyPositive\x10\x06\x12\x1f\n\x1bk_EUserReviewScore_Positive\x10\x07\x12#\n\x1fk_EUserReviewScore_VeryPositive\x10\x08\x12-\n)k_EUserReviewScore_OverwhelminglyPositive\x10\t*\xf7\x01\n\x10\x45TrailerCategory\x12\x1e\n\x1ak_ETrailerCategory_Invalid\x10\x00\x12\x1f\n\x1bk_ETrailerCategory_Gameplay\x10\x01\x12\x1d\n\x19k_ETrailerCategory_Teaser\x10\x02\x12 \n\x1ck_ETrailerCategory_Cinematic\x10\x03\x12\x1d\n\x19k_ETrailerCategory_Update\x10\x04\x12 \n\x1ck_ETrailerCategory_Accolades\x10\x05\x12 \n\x1ck_ETrailerCategory_Interview\x10\x06*\xa7\x02\n\x19\x45StoreBrowseFilterFailure\x12$\n k_EStoreBrowseFilterFailure_None\x10\x00\x12)\n%k_EStoreBrowseFilterFailure_Redundant\x10\n\x12,\n(k_EStoreBrowseFilterFailure_NotPreferred\x10\x14\x12-\n)k_EStoreBrowseFilterFailure_NotInterested\x10\x1e\x12/\n+k_EStoreBrowseFilterFailure_UnwantedContent\x10(\x12+\n\'k_EStoreBrowseFilterFailure_Unavailable\x10\x32*\xeb\x05\n\x0e\x45StoreLinkType\x12\x19\n\x15k_EStoreLinkType_None\x10\x00\x12\x1c\n\x18k_EStoreLinkType_YouTube\x10\x01\x12\x1d\n\x19k_EStoreLinkType_Facebook\x10\x02\x12\x1c\n\x18k_EStoreLinkType_Twitter\x10\x03\x12\x1b\n\x17k_EStoreLinkType_Twitch\x10\x04\x12\x1c\n\x18k_EStoreLinkType_Discord\x10\x05\x12\x17\n\x13k_EStoreLinkType_QQ\x10\x06\x12\x17\n\x13k_EStoreLinkType_VK\x10\x07\x12\x1d\n\x19k_EStoreLinkType_Bilibili\x10\x08\x12\x1a\n\x16k_EStoreLinkType_Weibo\x10\t\x12\x1b\n\x17k_EStoreLinkType_Reddit\x10\n\x12\x1e\n\x1ak_EStoreLinkType_Instagram\x10\x0b\x12\x1b\n\x17k_EStoreLinkType_Tumblr\x10\x0c\x12\x1a\n\x16k_EStoreLinkType_Tieba\x10\r\x12\x1b\n\x17k_EStoreLinkType_Tiktok\x10\x0e\x12\x1d\n\x19k_EStoreLinkType_Telegram\x10\x0f\x12\x1d\n\x19k_EStoreLinkType_LinkedIn\x10\x10\x12\x1b\n\x17k_EStoreLinkType_WeChat\x10\x11\x12\x1b\n\x17k_EStoreLinkType_QQLink\x10\x12\x12\x1b\n\x17k_EStoreLinkType_Douyin\x10\x13\x12\x1c\n\x18k_EStoreLinkType_Bluesky\x10\x14\x12\x1d\n\x19k_EStoreLinkType_Mastodon\x10\x15\x12\x1c\n\x18k_EStoreLinkType_Threads\x10\x16\x12\x1e\n\x1ak_EStoreLinkType_QQChannel\x10\x17\x12\x18\n\x14k_EStoreLinkType_MAX\x10\x18*\xf4\x01\n\x12\x45StoreCategoryType\x12!\n\x1dk_EStoreCategoryType_Category\x10\x00\x12)\n%k_EStoreCategoryType_SupportedPlayers\x10\x01\x12 \n\x1ck_EStoreCategoryType_Feature\x10\x02\x12*\n&k_EStoreCategoryType_ControllerSupport\x10\x03\x12$\n k_EStoreCategoryType_CloudGaming\x10\x04\x12\x1c\n\x18k_EStoreCategoryType_MAX\x10\x05\x32\xb8\x05\n\x0bStoreBrowse\x12K\n\x08GetItems\x12\x1e.CStoreBrowse_GetItems_Request\x1a\x1f.CStoreBrowse_GetItems_Response\x12i\n\x12GetStoreCategories\x12(.CStoreBrowse_GetStoreCategories_Request\x1a).CStoreBrowse_GetStoreCategories_Response\x12l\n\x13GetContentHubConfig\x12).CStoreBrowse_GetContentHubConfig_Request\x1a*.CStoreBrowse_GetContentHubConfig_Response\x12Z\n\rGetPriceStops\x12#.CStoreBrowse_GetPriceStops_Request\x1a$.CStoreBrowse_GetPriceStops_Response\x12Z\n\rGetDLCForApps\x12#.CStoreBrowse_GetDLCForApps_Request\x1a$.CStoreBrowse_GetDLCForApps_Response\x12\x66\n\x11GetDLCForAppsSolr\x12\'.CStoreBrowse_GetDLCForAppsSolr_Request\x1a(.CStoreBrowse_GetDLCForAppsSolr_Response\x12\x63\n\x10GetHardwareItems\x12&.CStoreBrowse_GetHardwareItems_Request\x1a\'.CStoreBrowse_GetHardwareItems_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_storebrowse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _ESTOREITEMTYPE._serialized_start=10302
  _ESTOREITEMTYPE._serialized_end=10558
  _ESTOREAPPTYPE._serialized_start=10561
  _ESTOREAPPTYPE._serialized_end=10988
  _EUSERREVIEWSCORE._serialized_start=10991
  _EUSERREVIEWSCORE._serialized_end=11380
  _ETRAILERCATEGORY._serialized_start=11383
  _ETRAILERCATEGORY._serialized_end=11630
  _ESTOREBROWSEFILTERFAILURE._serialized_start=11633
  _ESTOREBROWSEFILTERFAILURE._serialized_end=11928
  _ESTORELINKTYPE._serialized_start=11931
  _ESTORELINKTYPE._serialized_end=12678
  _ESTORECATEGORYTYPE._serialized_start=12681
  _ESTORECATEGORYTYPE._serialized_end=12925
  _STOREITEMID._serialized_start=152
  _STOREITEMID._serialized_end=274
  _STOREBROWSECONTEXT._serialized_start=276
  _STOREBROWSECONTEXT._serialized_end=376
  _STOREBROWSEITEMDATAREQUEST._serialized_start=379
  _STOREBROWSEITEMDATAREQUEST._serialized_end=942
  _CSTOREBROWSE_GETITEMS_REQUEST._serialized_start=945
  _CSTOREBROWSE_GETITEMS_REQUEST._serialized_end=1092
  _STOREITEM._serialized_start=1095
  _STOREITEM._serialized_end=6963
  _STOREITEM_RELATEDITEMS._serialized_start=2666
  _STOREITEM_RELATEDITEMS._serialized_end=2753
  _STOREITEM_INCLUDEDITEMS._serialized_start=2755
  _STOREITEM_INCLUDEDITEMS._serialized_end=2844
  _STOREITEM_CATEGORIES._serialized_start=2846
  _STOREITEM_CATEGORIES._serialized_end=2957
  _STOREITEM_REVIEWS._serialized_start=2960
  _STOREITEM_REVIEWS._serialized_end=3266
  _STOREITEM_REVIEWS_STOREREVIEWSUMMARY._serialized_start=3104
  _STOREITEM_REVIEWS_STOREREVIEWSUMMARY._serialized_end=3266
  _STOREITEM_BASICINFO._serialized_start=3269
  _STOREITEM_BASICINFO._serialized_end=3573
  _STOREITEM_BASICINFO_CREATORHOMELINK._serialized_start=3509
  _STOREITEM_BASICINFO_CREATORHOMELINK._serialized_end=3573
  _STOREITEM_TAG._serialized_start=3575
  _STOREITEM_TAG._serialized_end=3611
  _STOREITEM_ASSETS._serialized_start=3614
  _STOREITEM_ASSETS._serialized_end=4009
  _STOREITEM_RELEASEINFO._serialized_start=4012
  _STOREITEM_RELEASEINFO._serialized_end=4375
  _STOREITEM_PLATFORMS._serialized_start=4378
  _STOREITEM_PLATFORMS._serialized_end=4842
  _STOREITEM_PLATFORMS_VRSUPPORT._serialized_start=4716
  _STOREITEM_PLATFORMS_VRSUPPORT._serialized_end=4842
  _STOREITEM_PURCHASEOPTION._serialized_start=4845
  _STOREITEM_PURCHASEOPTION._serialized_end=5909
  _STOREITEM_PURCHASEOPTION_DISCOUNT._serialized_start=5626
  _STOREITEM_PURCHASEOPTION_DISCOUNT._serialized_end=5718
  _STOREITEM_PURCHASEOPTION_RECURRENCEINFO._serialized_start=5721
  _STOREITEM_PURCHASEOPTION_RECURRENCEINFO._serialized_end=5909
  _STOREITEM_SCREENSHOTS._serialized_start=5912
  _STOREITEM_SCREENSHOTS._serialized_end=6110
  _STOREITEM_SCREENSHOTS_SCREENSHOT._serialized_start=6063
  _STOREITEM_SCREENSHOTS_SCREENSHOT._serialized_end=6110
  _STOREITEM_TRAILERS._serialized_start=6113
  _STOREITEM_TRAILERS._serialized_end=6666
  _STOREITEM_TRAILERS_VIDEOSOURCE._serialized_start=6227
  _STOREITEM_TRAILERS_VIDEOSOURCE._serialized_end=6272
  _STOREITEM_TRAILERS_TRAILER._serialized_start=6275
  _STOREITEM_TRAILERS_TRAILER._serialized_end=6666
  _STOREITEM_SUPPORTEDLANGUAGE._serialized_start=6669
  _STOREITEM_SUPPORTEDLANGUAGE._serialized_end=6802
  _STOREITEM_FREEWEEKEND._serialized_start=6804
  _STOREITEM_FREEWEEKEND._serialized_end=6869
  _STOREITEM_LINK._serialized_start=6871
  _STOREITEM_LINK._serialized_end=6963
  _STOREGAMERATING._serialized_start=6966
  _STOREGAMERATING._serialized_end=7149
  _STOREBROWSEFILTERFAILURE._serialized_start=7152
  _STOREBROWSEFILTERFAILURE._serialized_end=7569
  _CSTOREBROWSE_GETITEMS_RESPONSE._serialized_start=7571
  _CSTOREBROWSE_GETITEMS_RESPONSE._serialized_end=7636
  _CSTOREBROWSE_GETSTORECATEGORIES_REQUEST._serialized_start=7638
  _CSTOREBROWSE_GETSTORECATEGORIES_REQUEST._serialized_end=7720
  _CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE._serialized_start=7723
  _CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE._serialized_end=8085
  _CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY._serialized_start=7840
  _CSTOREBROWSE_GETSTORECATEGORIES_RESPONSE_CATEGORY._serialized_end=8085
  _CSTOREBROWSE_GETCONTENTHUBCONFIG_REQUEST._serialized_start=8087
  _CSTOREBROWSE_GETCONTENTHUBCONFIG_REQUEST._serialized_end=8167
  _CSTOREBROWSE_GETCONTENTHUBCONFIG_RESPONSE._serialized_start=8170
  _CSTOREBROWSE_GETCONTENTHUBCONFIG_RESPONSE._serialized_end=8407
  _CSTOREBROWSE_GETCONTENTHUBCONFIG_RESPONSE_CONTENTHUBCONFIG._serialized_start=8296
  _CSTOREBROWSE_GETCONTENTHUBCONFIG_RESPONSE_CONTENTHUBCONFIG._serialized_end=8407
  _CSTOREBROWSE_GETPRICESTOPS_REQUEST._serialized_start=8409
  _CSTOREBROWSE_GETPRICESTOPS_REQUEST._serialized_end=8490
  _CSTOREBROWSE_GETPRICESTOPS_RESPONSE._serialized_start=8493
  _CSTOREBROWSE_GETPRICESTOPS_RESPONSE._serialized_end=8686
  _CSTOREBROWSE_GETPRICESTOPS_RESPONSE_PRICESTOP._serialized_start=8624
  _CSTOREBROWSE_GETPRICESTOPS_RESPONSE_PRICESTOP._serialized_end=8686
  _CSTOREBROWSE_GETDLCFORAPPS_REQUEST._serialized_start=8689
  _CSTOREBROWSE_GETDLCFORAPPS_REQUEST._serialized_end=8856
  _CSTOREBROWSE_GETDLCFORAPPS_RESPONSE._serialized_start=8859
  _CSTOREBROWSE_GETDLCFORAPPS_RESPONSE._serialized_end=9241
  _CSTOREBROWSE_GETDLCFORAPPS_RESPONSE_DLCDATA._serialized_start=9034
  _CSTOREBROWSE_GETDLCFORAPPS_RESPONSE_DLCDATA._serialized_end=9169
  _CSTOREBROWSE_GETDLCFORAPPS_RESPONSE_PLAYTIMEFORAPP._serialized_start=9171
  _CSTOREBROWSE_GETDLCFORAPPS_RESPONSE_PLAYTIMEFORAPP._serialized_end=9241
  _CSTOREBROWSE_GETDLCFORAPPSSOLR_REQUEST._serialized_start=9244
  _CSTOREBROWSE_GETDLCFORAPPSSOLR_REQUEST._serialized_end=9415
  _CSTOREBROWSE_GETDLCFORAPPSSOLR_RESPONSE._serialized_start=9418
  _CSTOREBROWSE_GETDLCFORAPPSSOLR_RESPONSE._serialized_end=9581
  _CSTOREBROWSE_GETDLCFORAPPSSOLR_RESPONSE_DLCLIST._serialized_start=9530
  _CSTOREBROWSE_GETDLCFORAPPSSOLR_RESPONSE_DLCLIST._serialized_end=9581
  _CSTOREBROWSE_GETHARDWAREITEMS_REQUEST._serialized_start=9583
  _CSTOREBROWSE_GETHARDWAREITEMS_REQUEST._serialized_end=9679
  _CHARDWAREPACKAGEDETAILS._serialized_start=9682
  _CHARDWAREPACKAGEDETAILS._serialized_end=10214
  _CSTOREBROWSE_GETHARDWAREITEMS_RESPONSE._serialized_start=10216
  _CSTOREBROWSE_GETHARDWAREITEMS_RESPONSE._serialized_end=10299
  _STOREBROWSE._serialized_start=12928
  _STOREBROWSE._serialized_end=13624
_builder.BuildServices(DESCRIPTOR, 'steammessages_storebrowse_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_inventory.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsteammessages_inventory.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"A\n\x1f\x43Inventory_GetInventory_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\"\x86\x01\n\x13\x43Inventory_Response\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x16\n\x0eremoveditemids\x18\x02 \x03(\x04\x12\x11\n\titem_json\x18\x03 \x01(\t\x12\x14\n\x0citemdef_json\x18\x04 \x01(\t\x12\x0e\n\x06ticket\x18\x05 \x01(\x0c\x12\x10\n\x08replayed\x18\x06 \x01(\x08\"\x8e\x01\n\x1f\x43Inventory_ExchangeItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x17\n\x0fmaterialsitemid\x18\x03 \x03(\x04\x12\x19\n\x11materialsquantity\x18\x04 \x03(\r\x12\x17\n\x0foutputitemdefid\x18\x05 \x01(\x04\"O\n-CInventory_GetEligiblePromoItemDefIDs_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\"D\n.CInventory_GetEligiblePromoItemDefIDs_Response\x12\x12\n\nitemdefids\x18\x01 \x03(\x04\"\xd6\x01\n\x1a\x43Inventory_AddItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\titemdefid\x18\x02 \x03(\x04\x12\x15\n\ritempropsjson\x18\x03 \x03(\t\x12\x14\n\x0citemquantity\x18\t \x03(\r\x12\x0f\n\x07steamid\x18\x04 \x01(\x04\x12\x0e\n\x06notify\x18\x05 \x01(\x08\x12\x11\n\trequestid\x18\x06 \x01(\x04\x12\x19\n\x11trade_restriction\x18\x07 \x01(\x08\x12\x1a\n\x0bis_purchase\x18\x08 \x01(\x08:\x05\x66\x61lse\"\xe5\x02\n\x1e\x43Inventory_ModifyItems_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x04\x12\x43\n\x07updates\x18\x03 \x03(\x0b\x32\x32.CInventory_ModifyItems_Request.ItemPropertyUpdate\x12\x11\n\ttimestamp\x18\x04 \x01(\r\x1a\xca\x01\n\x12ItemPropertyUpdate\x12\x0e\n\x06itemid\x18\x01 \x01(\x04\x12\x17\n\x0fremove_property\x18\x02 \x01(\x08\x12\x15\n\rproperty_name\x18\x03 \x01(\t\x12\x1b\n\x13property_value_bool\x18\x04 \x01(\x08\x12\x1a\n\x12property_value_int\x18\x05 \x01(\x03\x12\x1d\n\x15property_value_string\x18\x06 \x01(\t\x12\x1c\n\x14property_value_float\x18\x07 \x01(\x02\"F\n\"CInventory_ConsumePlaytime_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\titemdefid\x18\x02 \x01(\x04\"\x88\x01\n\x1e\x43Inventory_ConsumeItem_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\x12\x10\n\x08quantity\x18\x03 \x01(\r\x12\x11\n\ttimestamp\x18\x04 \x01(\t\x12\x0f\n\x07steamid\x18\x05 \x01(\x04\x12\x11\n\trequestid\x18\x06 \x01(\x04\"W\n!CInventory_DevSetNextDrop_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\titemdefid\x18\x02 \x01(\x04\x12\x10\n\x08\x64roptime\x18\x03 \x01(\t\"e\n!CInventory_SplitItemStack_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06itemid\x18\x02 \x01(\x04\x12\x10\n\x08quantity\x18\x03 \x01(\r\x12\x0f\n\x07steamid\x18\x05 \x01(\x04\"\x80\x01\n$CInventory_CombineItemStacks_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nfromitemid\x18\x02 \x01(\x04\x12\x12\n\ndestitemid\x18\x03 \x01(\x04\x12\x10\n\x08quantity\x18\x04 \x01(\r\x12\x0f\n\x07steamid\x18\x07 \x01(\x06\"2\n!CInventory_GetItemDefMeta_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"F\n\"CInventory_GetItemDefMeta_Response\x12\x10\n\x08modified\x18\x01 \x01(\r\x12\x0e\n\x06\x64igest\x18\x02 \x01(\t\"(\n&CInventory_GetUserPurchaseInfo_Request\"<\n\'CInventory_GetUserPurchaseInfo_Response\x12\x11\n\tecurrency\x18\x01 \x01(\x05\"\xb2\x01\n\x1f\x43Inventory_PurchaseInit_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08language\x18\x02 \x01(\x05\x12=\n\nline_items\x18\x03 \x03(\x0b\x32).CInventory_PurchaseInit_Request.LineItem\x1a/\n\x08LineItem\x12\x11\n\titemdefid\x18\x01 \x01(\x04\x12\x10\n\x08quantity\x18\x02 \x01(\r\"D\n CInventory_PurchaseInit_Response\x12\x0f\n\x07orderid\x18\x01 \x01(\x04\x12\x0f\n\x07transid\x18\x02 \x01(\x04\"W\n#CInventory_PurchaseFinalize_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08language\x18\x02 \x01(\x05\x12\x0f\n\x07orderid\x18\x03 \x01(\x04\"Q\n\x1e\x43Inventory_InspectItem_Request\x12\x11\n\titemdefid\x18\x01 \x01(\x04\x12\x0e\n\x06itemid\x18\x02 \x01(\x06\x12\x0c\n\x04tags\x18\x03 \x01(\t\"i\n&CInventoryClient_NewItems_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x30\n\x12inventory_response\x18\x02 \x01(\x0b\x32\x14.CInventory_Response2\x9b\n\n\tInventory\x12\x46\n\x0cGetInventory\x12 .CInventory_GetInventory_Request\x1a\x14.CInventory_Response\x12\x46\n\x0c\x45xchangeItem\x12 .CInventory_ExchangeItem_Request\x1a\x14.CInventory_Response\x12}\n\x1aGetEligiblePromoItemDefIDs\x12..CInventory_GetEligiblePromoItemDefIDs_Request\x1a/.CInventory_GetEligiblePromoItemDefIDs_Response\x12\x41\n\x0c\x41\x64\x64PromoItem\x12\x1b.CInventory_AddItem_Request\x1a\x14.CInventory_Response\x12H\n\x0fSafeModifyItems\x12\x1f.CInventory_ModifyItems_Request\x1a\x14.CInventory_Response\x12L\n\x0f\x43onsumePlaytime\x12#.CInventory_ConsumePlaytime_Request\x1a\x14.CInventory_Response\x12\x44\n\x0b\x43onsumeItem\x12\x1f.CInventory_ConsumeItem_Request\x1a\x14.CInventory_Response\x12\x44\n\x0f\x44\x65vGenerateItem\x12\x1b.CInventory_AddItem_Request\x1a\x14.CInventory_Response\x12J\n\x0e\x44\x65vSetNextDrop\x12\".CInventory_DevSetNextDrop_Request\x1a\x14.CInventory_Response\x12J\n\x0eSplitItemStack\x12\".CInventory_SplitItemStack_Request\x1a\x14.CInventory_Response\x12P\n\x11\x43ombineItemStacks\x12%.CInventory_CombineItemStacks_Request\x1a\x14.CInventory_Response\x12Y\n\x0eGetItemDefMeta\x12\".CInventory_GetItemDefMeta_Request\x1a#.CInventory_GetItemDefMeta_Response\x12h\n\x13GetUserPurchaseInfo\x12\'.CInventory_GetUserPurchaseInfo_Request\x1a(.CInventory_GetUserPurchaseInfo_Response\x12S\n\x0cPurchaseInit\x12 .CInventory_PurchaseInit_Request\x1a!.CInventory_PurchaseInit_Response\x12N\n\x10PurchaseFinalize\x12$.CInventory_PurchaseFinalize_Request\x1a\x14.CInventory_Response\x12\x44\n\x0bInspectItem\x12\x1f.CInventory_InspectItem_Request\x1a\x14.CInventory_Response2_\n\x0fInventoryClient\x12\x46\n\x0eNotifyNewItems\x12\'.CInventoryClient_NewItems_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_inventory_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _INVENTORYCLIENT._options = None
  _INVENTORYCLIENT._serialized_options = b'\300\265\030\002'
  _CINVENTORY_GETINVENTORY_REQUEST._serialized_start=93
  _CINVENTORY_GETINVENTORY_REQUEST._serialized_end=158
  _CINVENTORY_RESPONSE._serialized_start=161
  _CINVENTORY_RESPONSE._serialized_end=295
  _CINVENTORY_EXCHANGEITEM_REQUEST._serialized_start=298
  _CINVENTORY_EXCHANGEITEM_REQUEST._serialized_end=440
  _CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_REQUEST._serialized_start=442
  _CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_REQUEST._serialized_end=521
  _CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_RESPONSE._serialized_start=523
  _CINVENTORY_GETELIGIBLEPROMOITEMDEFIDS_RESPONSE._serialized_end=591
  _CINVENTORY_ADDITEM_REQUEST._serialized_start=594
  _CINVENTORY_ADDITEM_REQUEST._serialized_end=808
  _CINVENTORY_MODIFYITEMS_REQUEST._serialized_start=811
  _CINVENTORY_MODIFYITEMS_REQUEST._serialized_end=1168
  _CINVENTORY_MODIFYITEMS_REQUEST_ITEMPROPERTYUPDATE._serialized_start=966
  _CINVENTORY_MODIFYITEMS_REQUEST_ITEMPROPERTYUPDATE._serialized_end=1168
  _CINVENTORY_CONSUMEPLAYTIME_REQUEST._serialized_start=1170
  _CINVENTORY_CONSUMEPLAYTIME_REQUEST._serialized_end=1240
  _CINVENTORY_CONSUMEITEM_REQUEST._serialized_start=1243
  _CINVENTORY_CONSUMEITEM_REQUEST._serialized_end=1379
  _CINVENTORY_DEVSETNEXTDROP_REQUEST._serialized_start=1381
  _CINVENTORY_DEVSETNEXTDROP_REQUEST._serialized_end=1468
  _CINVENTORY_SPLITITEMSTACK_REQUEST._serialized_start=1470
  _CINVENTORY_SPLITITEMSTACK_REQUEST._serialized_end=1571
  _CINVENTORY_COMBINEITEMSTACKS_REQUEST._serialized_start=1574
  _CINVENTORY_COMBINEITEMSTACKS_REQUEST._serialized_end=1702
  _CINVENTORY_GETITEMDEFMETA_REQUEST._serialized_start=1704
  _CINVENTORY_GETITEMDEFMETA_REQUEST._serialized_end=1754
  _CINVENTORY_GETITEMDEFMETA_RESPONSE._serialized_start=1756
  _CINVENTORY_GETITEMDEFMETA_RESPONSE._serialized_end=1826
  _CINVENTORY_GETUSERPURCHASEINFO_REQUEST._serialized_start=1828
  _CINVENTORY_GETUSERPURCHASEINFO_REQUEST._serialized_end=1868
  _CINVENTORY_GETUSERPURCHASEINFO_RESPONSE._serialized_start=1870
  _CINVENTORY_GETUSERPURCHASEINFO_RESPONSE._serialized_end=1930
  _CINVENTORY_PURCHASEINIT_REQUEST._serialized_start=1933
  _CINVENTORY_PURCHASEINIT_REQUEST._serialized_end=2111
  _CINVENTORY_PURCHASEINIT_REQUEST_LINEITEM._serialized_start=2064
  _CINVENTORY_PURCHASEINIT_REQUEST_LINEITEM._serialized_end=2111
  _CINVENTORY_PURCHASEINIT_RESPONSE._serialized_start=2113
  _CINVENTORY_PURCHASEINIT_RESPONSE._serialized_end=2181
  _CINVENTORY_PURCHASEFINALIZE_REQUEST._serialized_start=2183
  _CINVENTORY_PURCHASEFINALIZE_REQUEST._serialized_end=2270
  _CINVENTORY_INSPECTITEM_REQUEST._serialized_start=2272
  _CINVENTORY_INSPECTITEM_REQUEST._serialized_end=2353
  _CINVENTORYCLIENT_NEWITEMS_NOTIFICATION._serialized_start=2355
  _CINVENTORYCLIENT_NEWITEMS_NOTIFICATION._serialized_end=2460
  _INVENTORY._serialized_start=2463
  _INVENTORY._serialized_end=3770
  _INVENTORYCLIENT._serialized_start=3772
  _INVENTORYCLIENT._serialized_end=3867
_builder.BuildServices(DESCRIPTOR, 'steammessages_inventory_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steamnetworkingsockets_messages_udp.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steamnetworkingsockets_messages_certs_pb2 as steamnetworkingsockets__messages__certs__pb2
import steam.protobufs.steamnetworkingsockets_messages_pb2 as steamnetworkingsockets__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)steamnetworkingsockets_messages_udp.proto\x1a+steamnetworkingsockets_messages_certs.proto\x1a%steamnetworkingsockets_messages.proto\"n\n%CMsgSteamSockets_UDP_ChallengeRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\x07\x12\x14\n\x0cmy_timestamp\x18\x03 \x01(\x06\x12\x18\n\x10protocol_version\x18\x04 \x01(\r\"\x81\x01\n#CMsgSteamSockets_UDP_ChallengeReply\x12\x15\n\rconnection_id\x18\x01 \x01(\x07\x12\x11\n\tchallenge\x18\x02 \x01(\x06\x12\x16\n\x0eyour_timestamp\x18\x03 \x01(\x06\x12\x18\n\x10protocol_version\x18\x04 \x01(\r\"\x91\x03\n#CMsgSteamSockets_UDP_ConnectRequest\x12\x1c\n\x14\x63lient_connection_id\x18\x01 \x01(\x07\x12\x11\n\tchallenge\x18\x02 \x01(\x06\x12\x14\n\x0cmy_timestamp\x18\x05 \x01(\x06\x12\x13\n\x0bping_est_ms\x18\x06 \x01(\r\x12\x37\n\x05\x63rypt\x18\x07 \x01(\x0b\x32(.CMsgSteamDatagramSessionCryptInfoSigned\x12\x31\n\x04\x63\x65rt\x18\x04 \x01(\x0b\x32#.CMsgSteamDatagramCertificateSigned\x12\x1f\n\x17legacy_protocol_version\x18\x08 \x01(\r\x12\x17\n\x0fidentity_string\x18\n \x01(\t\x12\x1e\n\x16legacy_client_steam_id\x18\x03 \x01(\x06\x12H\n\x16legacy_identity_binary\x18\t \x01(\x0b\x32(.CMsgSteamNetworkingIdentityLegacyBinary\"\xfc\x02\n\x1e\x43MsgSteamSockets_UDP_ConnectOK\x12\x1c\n\x14\x63lient_connection_id\x18\x01 \x01(\x07\x12\x1c\n\x14server_connection_id\x18\x05 \x01(\x07\x12\x16\n\x0eyour_timestamp\x18\x03 \x01(\x06\x12\x17\n\x0f\x64\x65lay_time_usec\x18\x04 \x01(\r\x12\x37\n\x05\x63rypt\x18\x07 \x01(\x0b\x32(.CMsgSteamDatagramSessionCryptInfoSigned\x12\x31\n\x04\x63\x65rt\x18\x08 \x01(\x0b\x32#.CMsgSteamDatagramCertificateSigned\x12\x17\n\x0fidentity_string\x18\x0b \x01(\t\x12\x1e\n\x16legacy_server_steam_id\x18\x02 \x01(\x06\x12H\n\x16legacy_identity_binary\x18\n \x01(\x0b\x32(.CMsgSteamNetworkingIdentityLegacyBinary\"\x81\x01\n%CMsgSteamSockets_UDP_ConnectionClosed\x12\x18\n\x10to_connection_id\x18\x04 \x01(\x07\x12\x1a\n\x12\x66rom_connection_id\x18\x05 \x01(\x07\x12\r\n\x05\x64\x65\x62ug\x18\x02 \x01(\t\x12\x13\n\x0breason_code\x18\x03 \x01(\r\"Y\n!CMsgSteamSockets_UDP_NoConnection\x12\x1a\n\x12\x66rom_connection_id\x18\x02 \x01(\x07\x12\x18\n\x10to_connection_id\x18\x03 \x01(\x07\"\xb7\x01\n\x1a\x43MsgSteamSockets_UDP_Stats\x12\x32\n\x05stats\x18\x01 \x01(\x0b\x32#.CMsgSteamDatagramConnectionQuality\x12\r\n\x05\x66lags\x18\x03 \x01(\r\"V\n\x05\x46lags\x12\x13\n\x0f\x41\x43K_REQUEST_E2E\x10\x02\x12\x19\n\x15\x41\x43K_REQUEST_IMMEDIATE\x10\x04\x12\x1d\n\x19NOT_PRIMARY_TRANSPORT_E2E\x10\x10*\xa5\x02\n\x18\x45SteamNetworkingUDPMsgID\x12-\n)k_ESteamNetworkingUDPMsg_ChallengeRequest\x10 \x12+\n\'k_ESteamNetworkingUDPMsg_ChallengeReply\x10!\x12+\n\'k_ESteamNetworkingUDPMsg_ConnectRequest\x10\"\x12&\n\"k_ESteamNetworkingUDPMsg_ConnectOK\x10#\x12-\n)k_ESteamNetworkingUDPMsg_ConnectionClosed\x10$\x12)\n%k_ESteamNetworkingUDPMsg_NoConnection\x10%B\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steamnetworkingsockets_messages_udp_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _ESTEAMNETWORKINGUDPMSGID._serialized_start=1570
  _ESTEAMNETWORKINGUDPMSGID._serialized_end=1863
  _CMSGSTEAMSOCKETS_UDP_CHALLENGEREQUEST._serialized_start=129
  _CMSGSTEAMSOCKETS_UDP_CHALLENGEREQUEST._serialized_end=239
  _CMSGSTEAMSOCKETS_UDP_CHALLENGEREPLY._serialized_start=242
  _CMSGSTEAMSOCKETS_UDP_CHALLENGEREPLY._serialized_end=371
  _CMSGSTEAMSOCKETS_UDP_CONNECTREQUEST._serialized_start=374
  _CMSGSTEAMSOCKETS_UDP_CONNECTREQUEST._serialized_end=775
  _CMSGSTEAMSOCKETS_UDP_CONNECTOK._serialized_start=778
  _CMSGSTEAMSOCKETS_UDP_CONNECTOK._serialized_end=1158
  _CMSGSTEAMSOCKETS_UDP_CONNECTIONCLOSED._serialized_start=1161
  _CMSGSTEAMSOCKETS_UDP_CONNECTIONCLOSED._serialized_end=1290
  _CMSGSTEAMSOCKETS_UDP_NOCONNECTION._serialized_start=1292
  _CMSGSTEAMSOCKETS_UDP_NOCONNECTION._serialized_end=1381
  _CMSGSTEAMSOCKETS_UDP_STATS._serialized_start=1384
  _CMSGSTEAMSOCKETS_UDP_STATS._serialized_end=1567
  _CMSGSTEAMSOCKETS_UDP_STATS_FLAGS._serialized_start=1481
  _CMSGSTEAMSOCKETS_UDP_STATS_FLAGS._serialized_end=1567
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_twofactor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsteammessages_twofactor.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\".\n\x17\x43TwoFactor_Time_Request\x12\x13\n\x0bsender_time\x18\x01 \x01(\x04\"\xa5\x02\n\x18\x43TwoFactor_Time_Response\x12\x13\n\x0bserver_time\x18\x01 \x01(\x04\x12\x1e\n\x16skew_tolerance_seconds\x18\x02 \x01(\x04\x12\x17\n\x0flarge_time_jink\x18\x03 \x01(\x04\x12\x1f\n\x17probe_frequency_seconds\x18\x04 \x01(\r\x12-\n%adjusted_time_probe_frequency_seconds\x18\x05 \x01(\r\x12$\n\x1chint_probe_frequency_seconds\x18\x06 \x01(\r\x12\x14\n\x0csync_timeout\x18\x07 \x01(\r\x12\x19\n\x11try_again_seconds\x18\x08 \x01(\r\x12\x14\n\x0cmax_attempts\x18\t \x01(\r\"{\n\x19\x43TwoFactor_Status_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12M\n\x07include\x18\x02 \x01(\x0e\x32\x1a.ETwoFactorStatusFieldFlag: k_ETwoFactorStatusFieldFlag_None\"\xa6\x01\n\x15\x43TwoFactor_UsageEvent\x12\x0c\n\x04time\x18\x01 \x01(\r\x12G\n\nusage_type\x18\x02 \x01(\x0e\x32\x14.ETwoFactorUsageType:\x1dk_ETwoFactorUsageType_Unknown\x12\x19\n\x11\x63onfirmation_type\x18\x03 \x01(\x05\x12\x1b\n\x13\x63onfirmation_action\x18\x04 \x01(\x05\"\xd6\x03\n\x1a\x43TwoFactor_Status_Response\x12\r\n\x05state\x18\x01 \x01(\r\x12\x1b\n\x13inactivation_reason\x18\x02 \x01(\r\x12\x1a\n\x12\x61uthenticator_type\x18\x03 \x01(\r\x12\x1d\n\x15\x61uthenticator_allowed\x18\x04 \x01(\x08\x12\x19\n\x11steamguard_scheme\x18\x05 \x01(\r\x12\x11\n\ttoken_gid\x18\x06 \x01(\t\x12\x17\n\x0f\x65mail_validated\x18\x07 \x01(\x08\x12\x19\n\x11\x64\x65vice_identifier\x18\x08 \x01(\t\x12\x14\n\x0ctime_created\x18\t \x01(\r\x12%\n\x1drevocation_attempts_remaining\x18\n \x01(\r\x12\x18\n\x10\x63lassified_agent\x18\x0b \x01(\t\x12$\n\x1c\x61llow_external_authenticator\x18\x0c \x01(\x08\x12\x18\n\x10time_transferred\x18\r \x01(\r\x12\x0f\n\x07version\x18\x0e \x01(\r\x12\x1f\n\x17last_seen_auth_token_id\x18\x0f \x01(\x06\x12&\n\x06usages\x18\x10 \x03(\x0b\x32\x16.CTwoFactor_UsageEvent\"\xca\x01\n#CTwoFactor_AddAuthenticator_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1a\n\x12\x61uthenticator_time\x18\x02 \x01(\x04\x12\x15\n\rserial_number\x18\x03 \x01(\x06\x12\x1a\n\x12\x61uthenticator_type\x18\x04 \x01(\r\x12\x19\n\x11\x64\x65vice_identifier\x18\x05 \x01(\t\x12\x14\n\x0chttp_headers\x18\x07 \x03(\t\x12\x12\n\x07version\x18\x08 \x01(\r:\x01\x31\"\xa4\x02\n$CTwoFactor_AddAuthenticator_Response\x12\x15\n\rshared_secret\x18\x01 \x01(\x0c\x12\x15\n\rserial_number\x18\x02 \x01(\x06\x12\x17\n\x0frevocation_code\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x13\n\x0bserver_time\x18\x05 \x01(\x04\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x06 \x01(\t\x12\x11\n\ttoken_gid\x18\x07 \x01(\t\x12\x17\n\x0fidentity_secret\x18\x08 \x01(\x0c\x12\x10\n\x08secret_1\x18\t \x01(\x0c\x12\x0e\n\x06status\x18\n \x01(\x05\x12\x19\n\x11phone_number_hint\x18\x0b \x01(\t\x12\x14\n\x0c\x63onfirm_type\x18\x0c \x01(\x05\"\xc0\x01\n+CTwoFactor_FinalizeAddAuthenticator_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1a\n\x12\x61uthenticator_code\x18\x02 \x01(\t\x12\x1a\n\x12\x61uthenticator_time\x18\x03 \x01(\x04\x12\x17\n\x0f\x61\x63tivation_code\x18\x04 \x01(\t\x12\x14\n\x0chttp_headers\x18\x05 \x03(\t\x12\x19\n\x11validate_sms_code\x18\x06 \x01(\x08\"d\n,CTwoFactor_FinalizeAddAuthenticator_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0bserver_time\x18\x03 \x01(\x04\x12\x0e\n\x06status\x18\x04 \x01(\x05\"\\\n%CTwoFactor_UpdateTokenVersion_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"(\n&CTwoFactor_UpdateTokenVersion_Response\"\x9e\x01\n&CTwoFactor_RemoveAuthenticator_Request\x12\x17\n\x0frevocation_code\x18\x02 \x01(\t\x12\x19\n\x11revocation_reason\x18\x05 \x01(\r\x12\x19\n\x11steamguard_scheme\x18\x06 \x01(\r\x12%\n\x1dremove_all_steamguard_cookies\x18\x07 \x01(\x08\"v\n\'CTwoFactor_RemoveAuthenticator_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0bserver_time\x18\x03 \x01(\x04\x12%\n\x1drevocation_attempts_remaining\x18\x05 \x01(\r\"9\n7CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request\"K\n8CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\"~\n:CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request\x12\x10\n\x08sms_code\x18\x01 \x01(\t\x12\x1a\n\x12generate_new_token\x18\x02 \x01(\x08\x12\x12\n\x07version\x18\x03 \x01(\r:\x01\x31\"\xb5\x02\n:CRemoveAuthenticatorViaChallengeContinue_Replacement_Token\x12\x15\n\rshared_secret\x18\x01 \x01(\x0c\x12\x15\n\rserial_number\x18\x02 \x01(\x06\x12\x17\n\x0frevocation_code\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x13\n\x0bserver_time\x18\x05 \x01(\x04\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x06 \x01(\t\x12\x11\n\ttoken_gid\x18\x07 \x01(\t\x12\x17\n\x0fidentity_secret\x18\x08 \x01(\x0c\x12\x10\n\x08secret_1\x18\t \x01(\x0c\x12\x0e\n\x06status\x18\n \x01(\x05\x12\x19\n\x11steamguard_scheme\x18\x0b \x01(\r\x12\x0f\n\x07steamid\x18\x0c \x01(\x06\"\xa6\x01\n;CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12V\n\x11replacement_token\x18\x02 \x01(\x0b\x32;.CRemoveAuthenticatorViaChallengeContinue_Replacement_Token*l\n\x19\x45TwoFactorStatusFieldFlag\x12$\n k_ETwoFactorStatusFieldFlag_None\x10\x00\x12)\n%k_ETwoFactorStatusFieldFlag_LastUsage\x10\x01*\xa7\x01\n\x13\x45TwoFactorUsageType\x12!\n\x1dk_ETwoFactorUsageType_Unknown\x10\x00\x12\x1e\n\x1ak_ETwoFactorUsageType_None\x10\x01\x12,\n(k_ETwoFactorUsageType_MobileConfirmation\x10\x02\x12\x1f\n\x1bk_ETwoFactorUsageType_Login\x10\x03\x32\x85\x07\n\tTwoFactor\x12@\n\tQueryTime\x12\x18.CTwoFactor_Time_Request\x1a\x19.CTwoFactor_Time_Response\x12\x46\n\x0bQueryStatus\x12\x1a.CTwoFactor_Status_Request\x1a\x1b.CTwoFactor_Status_Response\x12_\n\x10\x41\x64\x64\x41uthenticator\x12$.CTwoFactor_AddAuthenticator_Request\x1a%.CTwoFactor_AddAuthenticator_Response\x12w\n\x18\x46inalizeAddAuthenticator\x12,.CTwoFactor_FinalizeAddAuthenticator_Request\x1a-.CTwoFactor_FinalizeAddAuthenticator_Response\x12\x65\n\x12UpdateTokenVersion\x12&.CTwoFactor_UpdateTokenVersion_Request\x1a\'.CTwoFactor_UpdateTokenVersion_Response\x12h\n\x13RemoveAuthenticator\x12\'.CTwoFactor_RemoveAuthenticator_Request\x1a(.CTwoFactor_RemoveAuthenticator_Response\x12\x9b\x01\n$RemoveAuthenticatorViaChallengeStart\x12\x38.CTwoFactor_RemoveAuthenticatorViaChallengeStart_Request\x1a\x39.CTwoFactor_RemoveAuthenticatorViaChallengeStart_Response\x12\xa4\x01\n\'RemoveAuthenticatorViaChallengeContinue\x12;.CTwoFactor_RemoveAuthenticatorViaChallengeContinue_Request\x1a<.CTwoFactor_RemoveAuthenticatorViaChallengeContinue_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_twofactor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _ETWOFACTORSTATUSFIELDFLAG._serialized_start=3163
  _ETWOFACTORSTATUSFIELDFLAG._serialized_end=3271
  _ETWOFACTORUSAGETYPE._serialized_start=3274
  _ETWOFACTORUSAGETYPE._serialized_end=3441
  _CTWOFACTOR_TIME_REQUEST._serialized_start=93
  _CTWOFACTOR_TIME_REQUEST._serialized_end=139
  _CTWOFACTOR_TIME_RESPONSE._serialized_start=142
  _CTWOFACTOR_TIME_RESPONSE._serialized_end=435
  _CTWOFACTOR_STATUS_REQUEST._serialized_start=437
  _CTWOFACTOR_STATUS_REQUEST._serialized_end=560
  _CTWOFACTOR_USAGEEVENT._serialized_start=563
  _CTWOFACTOR_USAGEEVENT._serialized_end=729
  _CTWOFACTOR_STATUS_RESPONSE._serialized_start=732
  _CTWOFACTOR_STATUS_RESPONSE._serialized_end=1202
  _CTWOFACTOR_ADDAUTHENTICATOR_REQUEST._serialized_start=1205
  _CTWOFACTOR_ADDAUTHENTICATOR_REQUEST._serialized_end=1407
  _CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE._serialized_start=1410
  _CTWOFACTOR_ADDAUTHENTICATOR_RESPONSE._serialized_end=1702
  _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST._serialized_start=1705
  _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_REQUEST._serialized_end=1897
  _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE._serialized_start=1899
  _CTWOFACTOR_FINALIZEADDAUTHENTICATOR_RESPONSE._serialized_end=1999
  _CTWOFACTOR_UPDATETOKENVERSION_REQUEST._serialized_start=2001
  _CTWOFACTOR_UPDATETOKENVERSION_REQUEST._serialized_end=2093
  _CTWOFACTOR_UPDATETOKENVERSION_RESPONSE._serialized_start=2095
  _CTWOFACTOR_UPDATETOKENVERSION_RESPONSE._serialized_end=2135
  _CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST._serialized_start=2138
  _CTWOFACTOR_REMOVEAUTHENTICATOR_REQUEST._serialized_end=2296
  _CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE._serialized_start=2298
  _CTWOFACTOR_REMOVEAUTHENTICATOR_RESPONSE._serialized_end=2416
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_REQUEST._serialized_start=2418
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_REQUEST._serialized_end=2475
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_RESPONSE._serialized_start=2477
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGESTART_RESPONSE._serialized_end=2552
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST._serialized_start=2554
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_REQUEST._serialized_end=2680
  _CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN._serialized_start=2683
  _CREMOVEAUTHENTICATORVIACHALLENGECONTINUE_REPLACEMENT_TOKEN._serialized_end=2992
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE._serialized_start=2995
  _CTWOFACTOR_REMOVEAUTHENTICATORVIACHALLENGECONTINUE_RESPONSE._serialized_end=3161
  _TWOFACTOR._serialized_start=3444
  _TWOFACTOR._serialized_end=4345
_builder.BuildServices(DESCRIPTOR, 'steammessages_twofactor_pb2', globals())
# @@protoc_insertion_point(module_scope)



"""
This submodule contains various functionality related to Steam Guard.

:class:`SteamAuthenticator` provides methods for genereating codes
and enabling 2FA on a Steam account. Operations managing the authenticator
on an account require an instance of either :class:`.MobileWebAuth` or
:class:`.SteamClient`. The instance needs to be logged in.

Adding an authenticator

.. code:: python

    wa = MobileWebAuth('steamuser')
    wa.cli_login()

    sa = SteamAuthenticator(backend=wa)
    sa.add()    # SMS code will be send to the account's phone number
    sa.secrets  # dict with authenticator secrets (SAVE THEM!!)

    # save the secrets, for example to a file
    json.dump(sa.secrets, open('./mysecrets.json', 'w'))

    # HINT: You can stop here and add authenticator on your phone.
    #       The secrets will be the same, and you will be able to
    #       both use your phone and SteamAuthenticator.

    sa.finalize('SMS CODE')  # activate the authenticator
    sa.get_code()  # generate 2FA code for login
    sa.remove()  # removes the authenticator from the account

.. warning::
    Before you finalize the authenticator, make sure to save your secrets.
    Otherwise you will lose access to the account.

Once authenticator is enabled all you need is the secrets to generate codes.

.. code:: python

    secrets = json.load(open('./mysecrets.json'))

    sa = SteamAuthenticator(secrets)
    sa.get_code()

You can obtain the authenticator secrets from an Android device using
:func:`extract_secrets_from_android_rooted`. See the function docstring for
details on what is required for it to work.

Format of ``secrets.json`` file:

.. code:: json

    {
        "account_name": "<username>",               # account username
        "identity_secret": "<base64 encoded>",      # unknown
        "revocation_code": "R51234",                # revocation code
        "secret_1": "<base54 encoded>",             # unknown
        "serial_number": "1111222333344445555",     # serial number
        "server_time": "1600000000",                # creation timestamp
        "shared_secret": "<base65 encoded>",        # secret used for code generation
        "status": 1,                                # status, 1 = token active
        "token_gid": "a1a1a1a1a1a1a1a1",            # token gid
        "uri": "otpauth://totp/Steam:<username>?secret=<base32 encoded shared seceret>&issuer=Steam"
    }
"""
import json
import subprocess
import struct
import requests
from base64 import b64decode, b64encode
from binascii import hexlify
from time import time
from steam import webapi
from steam.enums import ETwoFactorTokenType
from steam.steamid import SteamID
from steam.core.crypto import hmac_sha1, sha1_hash
from steam.enums.common import EResult
from steam.webauth import MobileWebAuth
from steam.utils.proto import proto_to_dict


class SteamAuthenticator(object):
    """Add/Remove authenticator from an account. Generate 2FA and confirmation codes."""
    _finalize_attempts = 5
    backend = None               #: instance of :class:`.MobileWebAuth` or :class:`.SteamClient`
    steam_time_offset = None     #: offset from steam server time
    align_time_every = 0         #: how often to align time with Steam (``0`` never, otherwise interval in seconds)
    _offset_last_check = 0
    secrets = None               #: :class:`dict` with authenticator secrets

    def __init__(self, secrets=None, backend=None):
        """
        :param secret: a dict of authenticator secrets
        :type  secret: dict
        :param backend: logged on session for steam user
        :type  backend: :class:`.MobileWebAuth`, :class:`.SteamClient`
        """
        self.secrets = secrets or {}
        self.backend = backend

    def __getattr__(self, key):
        if key not in self.secrets:
            raise AttributeError("No %s attribute" % repr(key))
        return self.secrets[key]

    def get_time(self):
        """
        :return: Steam aligned timestamp
        :rtype: int
        """
        if (self.steam_time_offset is None
           or (self.align_time_every and (time() - self._offset_last_check) > self.align_time_every)
           ):
            self.steam_time_offset = get_time_offset()

            if self.steam_time_offset is not None:
                self._offset_last_check = time()

        return int(time() + (self.steam_time_offset or 0))

    def get_code(self, timestamp=None):
        """
        :param timestamp: time to use for code generation
        :type timestamp: int
        :return: two factor code
        :rtype: str
        """
        return generate_twofactor_code_for_time(b64decode(self.shared_secret),
                                                self.get_time() if timestamp is None else timestamp)

    def get_confirmation_key(self, tag='', timestamp=None):
        """
        :param tag: see :func:`generate_confirmation_key` for this value
        :type tag: str
        :param timestamp: time to use for code generation
        :type timestamp: int
        :return: trade confirmation key
        :rtype: str
        """
        return generate_confirmation_key(b64decode(self.identity_secret), tag,
                                         self.get_time() if timestamp is None else timestamp)

    def _send_request(self, action, params):
        backend = self.backend

        if isinstance(backend, MobileWebAuth):
            if not backend.logged_on:
                raise SteamAuthenticatorError("MobileWebAuth instance not logged in")

            params['access_token'] = backend.oauth_token
            params['http_timeout'] = 10

            try:
                resp = webapi.post('ITwoFactorService', action, 1, params=params)
            except requests.exceptions.RequestException as exp:
                raise SteamAuthenticatorError("Error adding via WebAPI: %s" % str(exp))

            resp = resp['response']
        else:
            if not backend.logged_on:
                raise SteamAuthenticatorError("SteamClient instance not logged in")

            resp = backend.send_um_and_wait("TwoFactor.%s#1" % action,
                                            params, timeout=10)

            if resp is None:
                raise SteamAuthenticatorError("Failed. Request timeout")
            if resp.header.eresult != EResult.OK:
                raise SteamAuthenticatorError("Failed: %s (%s)" % (resp.header.error_message,
                                                                   repr(resp.header.eresult)))

            resp = proto_to_dict(resp.body)

            if action == 'AddAuthenticator':
                for key in ['shared_secret', 'identity_secret', 'secret_1']:
                    resp[key] = b64encode(resp[key]).decode('ascii')

        return resp

    def add(self):
        """Add authenticator to an account.
        The account's phone number will receive a SMS code required for :meth:`finalize`.

        :raises: :class:`SteamAuthenticatorError`
        """
        if not self.has_phone_number():
            raise SteamAuthenticatorError("Account doesn't have a verified phone number")

        resp = self._send_request('AddAuthenticator', {
            'steamid': self.backend.steam_id,
            'authenticator_time': int(time()),
            'authenticator_type': int(ETwoFactorTokenType.ValveMobileApp),
            'device_identifier': generate_device_id(self.backend.steam_id),
            'sms_phone_id': '1',
        })

        if resp['status'] != EResult.OK:
            raise SteamAuthenticatorError("Failed to add authenticator. Error: %s" % repr(EResult(resp['status'])))

        self.secrets = resp
        self.steam_time_offset = int(resp['server_time']) - time()

    def finalize(self, activation_code):
        """Finalize authenticator with received SMS code

        :param activation_code: SMS code
        :type activation_code: str
        :raises: :class:`SteamAuthenticatorError`
        """
        resp = self._send_request('FinalizeAddAuthenticator', {
            'steamid': self.backend.steam_id,
            'authenticator_time': int(time()),
            'authenticator_code': self.get_code(),
            'activation_code': activation_code,
        })

        if resp['status'] != EResult.TwoFactorActivationCodeMismatch and resp.get('want_more', False) and self._finalize_attempts:
            self.steam_time_offset += 30
            self._finalize_attempts -= 1
            self.finalize(activation_code)
            return
        elif not resp['success']:
            self._finalize_attempts = 5
            raise SteamAuthenticatorError("Failed to finalize authenticator. Error: %s" % repr(EResult(resp['status'])))

        self.steam_time_offset = int(resp['server_time']) - time()

    def remove(self, revocation_code=None):
        """Remove authenticator

        :param revocation_code: revocation code for account (e.g. R12345)
        :type  revocation_code: str

        .. note::
            After removing authenticator Steam Guard will be set to email codes

        .. warning::
            Doesn't work via :class:`.SteamClient`. Disabled by Valve

        :raises: :class:`SteamAuthenticatorError`
        """
        if not self.secrets:
            raise SteamAuthenticatorError("No authenticator secrets available?")
        if not isinstance(self.backend, MobileWebAuth):
            raise SteamAuthenticatorError("Only available via MobileWebAuth")

        resp = self._send_request('RemoveAuthenticator', {
            'steamid': self.backend.steam_id,
            'revocation_code': revocation_code if revocation_code else self.revocation_code,
            'steamguard_scheme': 1,
        })

        if not resp['success']:
            raise SteamAuthenticatorError("Failed to remove authenticator. (attempts remaining: %s)" % (
                resp['revocation_attempts_remaining'],
                ))

        self.secrets.clear()

    def status(self):
        """Fetch authenticator status for the account

        :raises: :class:`SteamAuthenticatorError`
        :return: dict with status parameters
        :rtype: dict
        """
        return self._send_request('QueryStatus', {'steamid': self.backend.steam_id})

    def create_emergency_codes(self, code=None):
        """Generate emergency codes

        :param code: SMS code
        :type code: str
        :raises: :class:`SteamAuthenticatorError`
        :return: list of codes
        :rtype: list

        .. note::
            A confirmation code is required to generate emergency codes and this method needs
            to be called twice as shown below.

        .. code:: python

            sa.create_emergency_codes()              # request a SMS code
            sa.create_emergency_codes(code='12345')  # creates emergency codes
        """
        if code:
            return self._send_request('createemergencycodes', {'code': code}).get('codes', [])
        else:
            self._send_request('createemergencycodes', {})
            return None

    def destroy_emergency_codes(self):
        """Destroy all emergency codes

        :raises: :class:`SteamAuthenticatorError`
        """
        self._send_request('DestroyEmergencyCodes', {'steamid': self.backend.steam_id})

    def _get_web_session(self):
        """
        :return: authenticated web session
        :rtype: :class:`requests.Session`
        :raises: :class:`RuntimeError` when session is unavailable
        """
        if isinstance(self.backend, MobileWebAuth):
            return self.backend.session
        else:
            if self.backend.logged_on:
                sess = self.backend.get_web_session()

                if sess is None:
                    raise RuntimeError("Failed to get a web session. Try again in a few minutes")
                else:
                    return sess
            else:
                raise RuntimeError("SteamClient instance is not connected")

    def add_phone_number(self, phone_number):
        """Add phone number to account

        Steps:

        1. Call :meth:`add_phone_number()` then check ``email_confirmation`` key in the response

           i. On ``True``, user needs to click link in email, then step 2
           ii. On ``False``, SMS code is sent,  go to step 3

        2. Confirm email via :meth:`confirm_email()`, SMS code is sent
        3. Finalize phone number with SMS code :meth:`confirm_phone_number(sms_code)`

        :param phone_number: phone number with country code
        :type  phone_number: :class:`str`
        :return: see example below
        :rtype: :class:`dict`

        .. code:: python

            {'success': True,
             'email_confirmation': True,
             'error_text': '',
             'fatal': False}
        """
        sess = self._get_web_session()

        try:
            resp = sess.post('https://steamcommunity.com/steamguard/phoneajax',
                             data={
                                 'op': 'add_phone_number',
                                 'arg': phone_number,
                                 'checkfortos': 0,
                                 'skipvoip': 0,
                                 'sessionid': sess.cookies.get('sessionid', domain='steamcommunity.com'),
                                 },
                             timeout=15).json()
        except:
            return {'success': False}

        return resp

    def confirm_email(self):
        """Confirm email confirmation. See :meth:`add_phone_number()`

        .. note::
            If ``email_confirmation`` is ``True``, then user hasn't clicked the link yet.

        :return: see example below
        :rtype: :class:`dict`

        .. code:: python

            {'success': True,
             'email_confirmation': True,
             'error_text': '',
             'fatal': False}
        """
        sess = self._get_web_session()

        try:
            resp = sess.post('https://steamcommunity.com/steamguard/phoneajax',
                             data={
                                 'op': 'email_confirmation',
                                 'arg': '',
                                 'checkfortos': 1,
                                 'skipvoip': 1,
                                 'sessionid': sess.cookies.get('sessionid', domain='steamcommunity.com'),
                                 },
                             timeout=15).json()
        except:
            return {'fatal': True, 'success': False}

        return resp

    def confirm_phone_number(self, sms_code):
        """Confirm phone number with the recieved SMS code. See :meth:`add_phone_number()`

        :param sms_code: sms code
        :type  sms_code: :class:`str`
        :return: see example below
        :rtype: :class:`dict`

        .. code:: python

            {'success': True,
             'error_text': '',
             'fatal': False}
        """
        sess = self._get_web_session()

        try:
            resp = sess.post('https://steamcommunity.com/steamguard/phoneajax',
                             data={
                                 'op': 'check_sms_code',
                                 'arg': sms_code,
                                 'checkfortos': 1,
                                 'skipvoip': 1,
                                 'sessionid': sess.cookies.get('sessionid', domain='steamcommunity.com'),
                                 },
                             timeout=15).json()
        except:
            return {'success': False}

        return resp

    def has_phone_number(self):
        """Check whether the account has a verified phone number

        :return: see example below
        :rtype: :class:`dict`

        .. code:: python

            {'success': True,
             'has_phone': True,
             'error_text': '',
             'fatal': False}
        """
        sess = self._get_web_session()

        try:
            resp = sess.post('https://steamcommunity.com/steamguard/phoneajax',
                             data={
                                 'op': 'has_phone',
                                 'arg': '0',
                                 'checkfortos': 0,
                                 'skipvoip': 1,
                                 'sessionid': sess.cookies.get('sessionid', domain='steamcommunity.com'),
                                 },
                             timeout=15).json()
        except:
            return {'success': False}

        return resp

    def validate_phone_number(self, phone_number):
        """Test whether phone number is valid for Steam

        :param phone_number: phone number with country code
        :type  phone_number: :class:`str`
        :return: see example below
        :rtype: :class:`dict`

        .. code:: python

            {'is_fixed': False,
             'is_valid': False,
             'is_voip': True,
             'number': '+1 123-555-1111',
             'success': True}
        """
        sess = self._get_web_session()

        try:
            resp = sess.post('https://store.steampowered.com/phone/validate',
                             data={
                                'phoneNumber': phone_number,
                                'sessionID': sess.cookies.get('sessionid', domain='store.steampowered.com'),
                                },
                             allow_redirects=False,
                             timeout=15).json()
        except:
            resp = {'success': False}

        return resp


class SteamAuthenticatorError(Exception):
    pass


def generate_twofactor_code(shared_secret):
    """Generate Steam 2FA code for login with current time

    :param shared_secret: authenticator shared shared_secret
    :type shared_secret: bytes
    :return: steam two factor code
    :rtype: str
    """
    return generate_twofactor_code_for_time(shared_secret, time() + (get_time_offset() or 0))

def generate_twofactor_code_for_time(shared_secret, timestamp):
    """Generate Steam 2FA code for timestamp

    :param shared_secret: authenticator shared secret
    :type shared_secret: bytes
    :param timestamp: timestamp to use, if left out uses current time
    :type timestamp: int
    :return: steam two factor code
    :rtype: str
    """
    hmac = hmac_sha1(bytes(shared_secret),
                     struct.pack('>Q', int(timestamp)//30))  # this will NOT stop working in 2038

    start = ord(hmac[19:20]) & 0xF
    codeint = struct.unpack('>I', hmac[start:start+4])[0] & 0x7fffffff

    charset = '23456789BCDFGHJKMNPQRTVWXY'
    code = ''

    for _ in range(5):
        codeint, i = divmod(codeint, len(charset))
        code += charset[i]

    return code

def generate_confirmation_key(identity_secret, tag, timestamp):
    """Generate confirmation key for trades. Can only be used once.

    :param identity_secret: authenticator identity secret
    :type identity_secret: bytes
    :param tag: tag identifies what the request, see list below
    :type tag: str
    :param timestamp: timestamp to use for generating key
    :type timestamp: int
    :return: confirmation key
    :rtype: bytes

    Tag choices:

        * ``conf`` to load the confirmations page
        * ``details`` to load details about a trade
        * ``allow`` to confirm a trade
        * ``cancel`` to cancel a trade

    """
    data = struct.pack('>Q', int(timestamp)) + tag.encode('ascii') # this will NOT stop working in 2038
    return hmac_sha1(bytes(identity_secret), data)

def get_time_offset():
    """Get time offset from steam server time via WebAPI

    :return: time offset (``None`` when Steam WebAPI fails to respond)
    :rtype: :class:`int`, :class:`None`
    """
    try:
        resp = webapi.post('ITwoFactorService', 'QueryTime', 1, params={'http_timeout': 10})
    except:
        return None

    ts = int(time())
    return int(resp.get('response', {}).get('server_time', ts)) - ts

def generate_device_id(steamid):
    """Generate Android device id

    :param steamid: Steam ID
    :type steamid: :class:`.SteamID`, :class:`int`
    :return: android device id
    :rtype: str
    """
    h = hexlify(sha1_hash(str(steamid).encode('ascii'))).decode('ascii')
    return "android:%s-%s-%s-%s-%s" % (h[:8], h[8:12], h[12:16], h[16:20], h[20:32])

def extract_secrets_from_android_rooted(adb_path='adb'):
    """Extract Steam Authenticator secrets from a rooted Android device

    Prerequisite for this to work:

        - rooted android device
        - `adb binary <https://developer.android.com/studio/command-line/adb.html>`_
        - device in debug mode, connected and paired

    .. note::
        If you know how to make this work, without requiring the device to be rooted,
        please open a issue on github. Thanks

    :param adb_path: path to adb binary
    :type adb_path: str
    :raises: When there is any problem
    :return: all secrets from the device, steamid as key
    :rtype: dict
    """
    data = subprocess.check_output([
        adb_path, 'shell', 'su', '-c',
        "'cat /data/data/com.valvesoftware.android.steam.community/files/Steamguard*'"
        ])

    # When adb daemon is not running, `adb` will print a couple of lines before our data.
    # The data doesn't have new lines and its always on the last line.
    data = data.decode('utf-8').split('\n')[-1]

    if data[0] != "{":
        raise RuntimeError("Got invalid data: %s" % repr(data))

    return {int(x['steamid']): x
            for x in map(json.loads, data.replace("}{", '}|||||{').split('|||||'))}



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientnotificationtypes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+steammessages_clientnotificationtypes.proto\"4\n#CClientNotificationCloudSyncFailure\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"5\n$CClientNotificationCloudSyncConflict\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"b\n\x1d\x43\x43lientNotificationScreenshot\x12\x19\n\x11screenshot_handle\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tlocal_url\x18\x03 \x01(\t\"H\n$CClientNotificationDownloadCompleted\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tdlc_appid\x18\x02 \x01(\r\"2\n\x1f\x43\x43lientNotificationFriendInvite\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"A\n%CClientNotificationFriendInviteRollup\x12\x18\n\x10new_invite_count\x18\x01 \x01(\r\"E\n\x1f\x43\x43lientNotificationFriendInGame\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x11\n\tgame_name\x18\x02 \x01(\t\"2\n\x1f\x43\x43lientNotificationFriendOnline\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"\x8a\x02\n\x1e\x43\x43lientNotificationAchievement\x12\x16\n\x0e\x61\x63hievement_id\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\x10\n\x08\x61\x63hieved\x18\x06 \x01(\x08\x12\x16\n\x0ertime_unlocked\x18\x07 \x01(\r\x12\x14\n\x0cmin_progress\x18\x08 \x01(\x02\x12\x18\n\x10\x63urrent_progress\x18\t \x01(\x02\x12\x14\n\x0cmax_progress\x18\n \x01(\x02\x12\x1b\n\x13global_achieved_pct\x18\x0b \x01(\x02\"6\n\x1d\x43\x43lientNotificationLowBattery\x12\x15\n\rpct_remaining\x18\x01 \x01(\x02\"x\n\x1f\x43\x43lientNotificationSystemUpdate\x12U\n\x04type\x18\x01 \x01(\x0e\x32\x1e.ESystemUpdateNotificationType:\'k_ESystemUpdateNotificationType_Invalid\"\x9e\x01\n CClientNotificationFriendMessage\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x12\x0c\n\x04icon\x18\x05 \x01(\t\x12\x16\n\x0enotificationid\x18\x06 \x01(\r\x12\x19\n\x11response_steamurl\x18\x07 \x01(\t\"\xc6\x01\n#CClientNotificationGroupChatMessage\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x16\n\x0esteamid_sender\x18\x02 \x01(\t\x12\x15\n\rchat_group_id\x18\x03 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x0c\n\x04\x62ody\x18\x06 \x01(\t\x12\x0f\n\x07rawbody\x18\x07 \x01(\t\x12\x0c\n\x04icon\x18\x08 \x01(\t\x12\x16\n\x0enotificationid\x18\t \x01(\r\"i\n:CClientNotificationFamilySharingDeviceAuthorizationChanged\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\x01 \x01(\r\x12\x12\n\nauthorized\x18\x02 \x01(\x08\"p\n+CClientNotificationFamilySharingStopPlaying\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\x01 \x01(\r\x12\x19\n\x11seconds_remaining\x18\x02 \x01(\r\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\"K\n0CClientNotificationFamilySharingLibraryAvailable\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\x01 \x01(\r\"7\n$CClientNotificationIncomingVoiceChat\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"*\n(CClientNotificationClaimSteamDeckRewards\"6\n\x1f\x43\x43lientNotificationGiftReceived\x12\x13\n\x0bsender_name\x18\x01 \x01(\t\"Y\n#CClientNotificationItemAnnouncement\x12\x16\n\x0enew_item_count\x18\x01 \x01(\r\x12\x1a\n\x12new_backpack_items\x18\x02 \x01(\x08\"*\n(CClientNotificationHardwareSurveyPending\"7\n\x1f\x43\x43lientNotificationLowDiskSpace\x12\x14\n\x0c\x66older_index\x18\x01 \x01(\r\"W\n%CClientNotificationBatteryTemperature\x12\x13\n\x0btemperature\x18\x01 \x01(\r\x12\x19\n\x11notification_type\x18\x02 \x01(\t\",\n*CClientNotificationDockUnsupportedFirmware\"H\n$CClientNotificationPeerContentUpload\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tpeer_name\x18\x02 \x01(\t\"N\n2CClientNotificationCannotReadControllerGuideButton\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\x05\"(\n&CClientNotificationOverlaySplashScreen\"L\n,CClientNotificationBroadcastAvailableToWatch\x12\x1c\n\x14\x62roadcast_permission\x18\x01 \x01(\x05\"\x87\x01\n&CClientNotificationTimedTrialRemaining\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0f\n\x07offline\x18\x03 \x01(\x08\x12\x17\n\x0f\x61llowed_seconds\x18\x04 \x01(\r\x12\x16\n\x0eplayed_seconds\x18\x05 \x01(\r\"!\n\x1f\x43\x43lientNotificationLoginRefresh\"!\n\x1f\x43\x43lientNotificationTimerExpired\"b\n-CClientNotificationSteamInputActionSetChanged\x12\x18\n\x10\x63ontroller_index\x18\x01 \x01(\x05\x12\x17\n\x0f\x61\x63tion_set_name\x18\x02 \x01(\t\"O\n)CClientNotificationRemoteClientConnection\x12\x0f\n\x07machine\x18\x01 \x01(\t\x12\x11\n\tconnected\x18\x02 \x01(\x08\"P\n*CClientNotificationRemoteClientStartStream\x12\x0f\n\x07machine\x18\x01 \x01(\t\x12\x11\n\tgame_name\x18\x02 \x01(\t\"d\n,CClientNotificationStreamingClientConnection\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x0f\n\x07machine\x18\x02 \x01(\t\x12\x11\n\tconnected\x18\x03 \x01(\x08\"N\n\"CClientNotificationPlaytimeWarning\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1a\n\x12playtime_remaining\x18\x02 \x01(\r\"\x84\x01\n%CClientNotificationGameRecordingError\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12J\n\nerror_type\x18\x02 \x01(\x0e\x32\x18.EGameRecordingErrorType:\x1ck_EGameRecordingErrorGeneral\"8\n%CClientNotificationGameRecordingStart\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\"_\n$CClientNotificationGameRecordingStop\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x0f\n\x07\x63lip_id\x18\x02 \x01(\t\x12\x15\n\rduration_secs\x18\x03 \x01(\x02\"B\n/CClientNotificationGameRecordingUserMarkerAdded\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\"f\n+CClientNotificationGameRecordingInstantClip\x12\x0f\n\x07game_id\x18\x01 \x01(\x06\x12\x0f\n\x07\x63lip_id\x18\x02 \x01(\t\x12\x15\n\rduration_secs\x18\x03 \x01(\x02*\xca\x16\n\x17\x45\x43lientNotificationType\x12%\n!k_EClientNotificationType_Invalid\x10\x00\x12/\n+k_EClientNotificationType_DownloadCompleted\x10\x01\x12*\n&k_EClientNotificationType_FriendInvite\x10\x02\x12*\n&k_EClientNotificationType_FriendInGame\x10\x03\x12*\n&k_EClientNotificationType_FriendOnline\x10\x04\x12)\n%k_EClientNotificationType_Achievement\x10\x05\x12(\n$k_EClientNotificationType_LowBattery\x10\x06\x12*\n&k_EClientNotificationType_SystemUpdate\x10\x07\x12+\n\'k_EClientNotificationType_FriendMessage\x10\x08\x12.\n*k_EClientNotificationType_GroupChatMessage\x10\t\x12\x30\n,k_EClientNotificationType_FriendInviteRollup\x10\n\x12\x36\n2k_EClientNotificationType_FamilySharingStopPlaying\x10\x0c\x12(\n$k_EClientNotificationType_Screenshot\x10\x0e\x12.\n*k_EClientNotificationType_CloudSyncFailure\x10\x0f\x12/\n+k_EClientNotificationType_CloudSyncConflict\x10\x10\x12/\n+k_EClientNotificationType_IncomingVoiceChat\x10\x11\x12\x33\n/k_EClientNotificationType_ClaimSteamDeckRewards\x10\x12\x12*\n&k_EClientNotificationType_GiftReceived\x10\x13\x12.\n*k_EClientNotificationType_ItemAnnouncement\x10\x14\x12,\n(k_EClientNotificationType_HardwareSurvey\x10\x15\x12*\n&k_EClientNotificationType_LowDiskSpace\x10\x16\x12\x30\n,k_EClientNotificationType_BatteryTemperature\x10\x17\x12\x35\n1k_EClientNotificationType_DockUnsupportedFirmware\x10\x18\x12/\n+k_EClientNotificationType_PeerContentUpload\x10\x19\x12=\n9k_EClientNotificationType_CannotReadControllerGuideButton\x10\x1a\x12%\n!k_EClientNotificationType_Comment\x10\x1b\x12&\n\"k_EClientNotificationType_Wishlist\x10\x1c\x12(\n$k_EClientNotificationType_TradeOffer\x10\x1d\x12\'\n#k_EClientNotificationType_AsyncGame\x10\x1e\x12%\n!k_EClientNotificationType_General\x10\x1f\x12)\n%k_EClientNotificationType_HelpRequest\x10 \x12\x31\n-k_EClientNotificationType_OverlaySplashScreen\x10!\x12\x37\n3k_EClientNotificationType_BroadcastAvailableToWatch\x10\"\x12\x31\n-k_EClientNotificationType_TimedTrialRemaining\x10#\x12*\n&k_EClientNotificationType_LoginRefresh\x10$\x12\'\n#k_EClientNotificationType_MajorSale\x10%\x12*\n&k_EClientNotificationType_TimerExpired\x10&\x12*\n&k_EClientNotificationType_ModeratorMsg\x10\'\x12\x38\n4k_EClientNotificationType_SteamInputActionSetChanged\x10(\x12\x34\n0k_EClientNotificationType_RemoteClientConnection\x10)\x12\x35\n1k_EClientNotificationType_RemoteClientStartStream\x10*\x12\x37\n3k_EClientNotificationType_StreamingClientConnection\x10+\x12*\n&k_EClientNotificationType_FamilyInvite\x10,\x12-\n)k_EClientNotificationType_PlaytimeWarning\x10-\x12\x33\n/k_EClientNotificationType_FamilyPurchaseRequest\x10.\x12;\n7k_EClientNotificationType_FamilyPurchaseRequestResponse\x10/\x12\x34\n0k_EClientNotificationType_ParentalFeatureRequest\x10\x30\x12\x35\n1k_EClientNotificationType_ParentalPlaytimeRequest\x10\x31\x12\x30\n,k_EClientNotificationType_GameRecordingError\x10\x32\x12\x35\n1k_EClientNotificationType_ParentalFeatureResponse\x10\x33\x12\x36\n2k_EClientNotificationType_ParentalPlaytimeResponse\x10\x34\x12\x30\n,k_EClientNotificationType_RequestedGameAdded\x10\x35\x12,\n(k_EClientNotificationType_ClipDownloaded\x10\x36\x12\x30\n,k_EClientNotificationType_GameRecordingStart\x10\x37\x12/\n+k_EClientNotificationType_GameRecordingStop\x10\x38\x12:\n6k_EClientNotificationType_GameRecordingUserMarkerAdded\x10\x39\x12\x36\n2k_EClientNotificationType_GameRecordingInstantClip\x10:\x12,\n(k_EClientNotificationType_PlaytestInvite\x10;\x12+\n\'k_EClientNotificationType_TradeReversal\x10<*\xad\x01\n\x1d\x45SystemUpdateNotificationType\x12+\n\'k_ESystemUpdateNotificationType_Invalid\x10\x00\x12-\n)k_ESystemUpdateNotificationType_Available\x10\x01\x12\x30\n,k_ESystemUpdateNotificationType_NeedsRestart\x10\x02*b\n\x17\x45GameRecordingErrorType\x12 \n\x1ck_EGameRecordingErrorGeneral\x10\x01\x12%\n!k_EGameRecordingErrorLowDiskSpace\x10\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientnotificationtypes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _ECLIENTNOTIFICATIONTYPE._serialized_start=3553
  _ECLIENTNOTIFICATIONTYPE._serialized_end=6443
  _ESYSTEMUPDATENOTIFICATIONTYPE._serialized_start=6446
  _ESYSTEMUPDATENOTIFICATIONTYPE._serialized_end=6619
  _EGAMERECORDINGERRORTYPE._serialized_start=6621
  _EGAMERECORDINGERRORTYPE._serialized_end=6719
  _CCLIENTNOTIFICATIONCLOUDSYNCFAILURE._serialized_start=47
  _CCLIENTNOTIFICATIONCLOUDSYNCFAILURE._serialized_end=99
  _CCLIENTNOTIFICATIONCLOUDSYNCCONFLICT._serialized_start=101
  _CCLIENTNOTIFICATIONCLOUDSYNCCONFLICT._serialized_end=154
  _CCLIENTNOTIFICATIONSCREENSHOT._serialized_start=156
  _CCLIENTNOTIFICATIONSCREENSHOT._serialized_end=254
  _CCLIENTNOTIFICATIONDOWNLOADCOMPLETED._serialized_start=256
  _CCLIENTNOTIFICATIONDOWNLOADCOMPLETED._serialized_end=328
  _CCLIENTNOTIFICATIONFRIENDINVITE._serialized_start=330
  _CCLIENTNOTIFICATIONFRIENDINVITE._serialized_end=380
  _CCLIENTNOTIFICATIONFRIENDINVITEROLLUP._serialized_start=382
  _CCLIENTNOTIFICATIONFRIENDINVITEROLLUP._serialized_end=447
  _CCLIENTNOTIFICATIONFRIENDINGAME._serialized_start=449
  _CCLIENTNOTIFICATIONFRIENDINGAME._serialized_end=518
  _CCLIENTNOTIFICATIONFRIENDONLINE._serialized_start=520
  _CCLIENTNOTIFICATIONFRIENDONLINE._serialized_end=570
  _CCLIENTNOTIFICATIONACHIEVEMENT._serialized_start=573
  _CCLIENTNOTIFICATIONACHIEVEMENT._serialized_end=839
  _CCLIENTNOTIFICATIONLOWBATTERY._serialized_start=841
  _CCLIENTNOTIFICATIONLOWBATTERY._serialized_end=895
  _CCLIENTNOTIFICATIONSYSTEMUPDATE._serialized_start=897
  _CCLIENTNOTIFICATIONSYSTEMUPDATE._serialized_end=1017
  _CCLIENTNOTIFICATIONFRIENDMESSAGE._serialized_start=1020
  _CCLIENTNOTIFICATIONFRIENDMESSAGE._serialized_end=1178
  _CCLIENTNOTIFICATIONGROUPCHATMESSAGE._serialized_start=1181
  _CCLIENTNOTIFICATIONGROUPCHATMESSAGE._serialized_end=1379
  _CCLIENTNOTIFICATIONFAMILYSHARINGDEVICEAUTHORIZATIONCHANGED._serialized_start=1381
  _CCLIENTNOTIFICATIONFAMILYSHARINGDEVICEAUTHORIZATIONCHANGED._serialized_end=1486
  _CCLIENTNOTIFICATIONFAMILYSHARINGSTOPPLAYING._serialized_start=1488
  _CCLIENTNOTIFICATIONFAMILYSHARINGSTOPPLAYING._serialized_end=1600
  _CCLIENTNOTIFICATIONFAMILYSHARINGLIBRARYAVAILABLE._serialized_start=1602
  _CCLIENTNOTIFICATIONFAMILYSHARINGLIBRARYAVAILABLE._serialized_end=1677
  _CCLIENTNOTIFICATIONINCOMINGVOICECHAT._serialized_start=1679
  _CCLIENTNOTIFICATIONINCOMINGVOICECHAT._serialized_end=1734
  _CCLIENTNOTIFICATIONCLAIMSTEAMDECKREWARDS._serialized_start=1736
  _CCLIENTNOTIFICATIONCLAIMSTEAMDECKREWARDS._serialized_end=1778
  _CCLIENTNOTIFICATIONGIFTRECEIVED._serialized_start=1780
  _CCLIENTNOTIFICATIONGIFTRECEIVED._serialized_end=1834
  _CCLIENTNOTIFICATIONITEMANNOUNCEMENT._serialized_start=1836
  _CCLIENTNOTIFICATIONITEMANNOUNCEMENT._serialized_end=1925
  _CCLIENTNOTIFICATIONHARDWARESURVEYPENDING._serialized_start=1927
  _CCLIENTNOTIFICATIONHARDWARESURVEYPENDING._serialized_end=1969
  _CCLIENTNOTIFICATIONLOWDISKSPACE._serialized_start=1971
  _CCLIENTNOTIFICATIONLOWDISKSPACE._serialized_end=2026
  _CCLIENTNOTIFICATIONBATTERYTEMPERATURE._serialized_start=2028
  _CCLIENTNOTIFICATIONBATTERYTEMPERATURE._serialized_end=2115
  _CCLIENTNOTIFICATIONDOCKUNSUPPORTEDFIRMWARE._serialized_start=2117
  _CCLIENTNOTIFICATIONDOCKUNSUPPORTEDFIRMWARE._serialized_end=2161
  _CCLIENTNOTIFICATIONPEERCONTENTUPLOAD._serialized_start=2163
  _CCLIENTNOTIFICATIONPEERCONTENTUPLOAD._serialized_end=2235
  _CCLIENTNOTIFICATIONCANNOTREADCONTROLLERGUIDEBUTTON._serialized_start=2237
  _CCLIENTNOTIFICATIONCANNOTREADCONTROLLERGUIDEBUTTON._serialized_end=2315
  _CCLIENTNOTIFICATIONOVERLAYSPLASHSCREEN._serialized_start=2317
  _CCLIENTNOTIFICATIONOVERLAYSPLASHSCREEN._serialized_end=2357
  _CCLIENTNOTIFICATIONBROADCASTAVAILABLETOWATCH._serialized_start=2359
  _CCLIENTNOTIFICATIONBROADCASTAVAILABLETOWATCH._serialized_end=2435
  _CCLIENTNOTIFICATIONTIMEDTRIALREMAINING._serialized_start=2438
  _CCLIENTNOTIFICATIONTIMEDTRIALREMAINING._serialized_end=2573
  _CCLIENTNOTIFICATIONLOGINREFRESH._serialized_start=2575
  _CCLIENTNOTIFICATIONLOGINREFRESH._serialized_end=2608
  _CCLIENTNOTIFICATIONTIMEREXPIRED._serialized_start=2610
  _CCLIENTNOTIFICATIONTIMEREXPIRED._serialized_end=2643
  _CCLIENTNOTIFICATIONSTEAMINPUTACTIONSETCHANGED._serialized_start=2645
  _CCLIENTNOTIFICATIONSTEAMINPUTACTIONSETCHANGED._serialized_end=2743
  _CCLIENTNOTIFICATIONREMOTECLIENTCONNECTION._serialized_start=2745
  _CCLIENTNOTIFICATIONREMOTECLIENTCONNECTION._serialized_end=2824
  _CCLIENTNOTIFICATIONREMOTECLIENTSTARTSTREAM._serialized_start=2826
  _CCLIENTNOTIFICATIONREMOTECLIENTSTARTSTREAM._serialized_end=2906
  _CCLIENTNOTIFICATIONSTREAMINGCLIENTCONNECTION._serialized_start=2908
  _CCLIENTNOTIFICATIONSTREAMINGCLIENTCONNECTION._serialized_end=3008
  _CCLIENTNOTIFICATIONPLAYTIMEWARNING._serialized_start=3010
  _CCLIENTNOTIFICATIONPLAYTIMEWARNING._serialized_end=3088
  _CCLIENTNOTIFICATIONGAMERECORDINGERROR._serialized_start=3091
  _CCLIENTNOTIFICATIONGAMERECORDINGERROR._serialized_end=3223
  _CCLIENTNOTIFICATIONGAMERECORDINGSTART._serialized_start=3225
  _CCLIENTNOTIFICATIONGAMERECORDINGSTART._serialized_end=3281
  _CCLIENTNOTIFICATIONGAMERECORDINGSTOP._serialized_start=3283
  _CCLIENTNOTIFICATIONGAMERECORDINGSTOP._serialized_end=3378
  _CCLIENTNOTIFICATIONGAMERECORDINGUSERMARKERADDED._serialized_start=3380
  _CCLIENTNOTIFICATIONGAMERECORDINGUSERMARKERADDED._serialized_end=3446
  _CCLIENTNOTIFICATIONGAMERECORDINGINSTANTCLIP._serialized_start=3448
  _CCLIENTNOTIFICATIONGAMERECORDINGINSTANTCLIP._serialized_end=3550
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_gamenetworking.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"steammessages_gamenetworking.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"P\n&CGameNetworking_AllocateFakeIP_Request\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x16\n\x0enum_fake_ports\x18\x02 \x01(\r\"N\n\'CGameNetworking_AllocateFakeIP_Response\x12\x0f\n\x07\x66\x61ke_ip\x18\x01 \x01(\x07\x12\x12\n\nfake_ports\x18\x02 \x03(\r\"a\n*CGameNetworking_ReleaseFakeIP_Notification\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x0f\n\x07\x66\x61ke_ip\x18\x02 \x01(\x07\x12\x12\n\nfake_ports\x18\x03 \x03(\r2\xc6\x01\n\x0eGameNetworking\x12\x63\n\x0e\x41llocateFakeIP\x12\'.CGameNetworking_AllocateFakeIP_Request\x1a(.CGameNetworking_AllocateFakeIP_Response\x12O\n\x13NotifyReleaseFakeIP\x12+.CGameNetworking_ReleaseFakeIP_Notification\x1a\x0b.NoResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_gamenetworking_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CGAMENETWORKING_ALLOCATEFAKEIP_REQUEST._serialized_start=98
  _CGAMENETWORKING_ALLOCATEFAKEIP_REQUEST._serialized_end=178
  _CGAMENETWORKING_ALLOCATEFAKEIP_RESPONSE._serialized_start=180
  _CGAMENETWORKING_ALLOCATEFAKEIP_RESPONSE._serialized_end=258
  _CGAMENETWORKING_RELEASEFAKEIP_NOTIFICATION._serialized_start=260
  _CGAMENETWORKING_RELEASEFAKEIP_NOTIFICATION._serialized_end=357
  _GAMENETWORKING._serialized_start=360
  _GAMENETWORKING._serialized_end=558
_builder.BuildServices(DESCRIPTOR, 'steammessages_gamenetworking_pb2', globals())
# @@protoc_insertion_point(module_scope)
